/****************************************************************************
** Meta object code from reading C++ file 'qvcandlestickmodelmapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/candlestickchart/qvcandlestickmodelmapper.h"
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvcandlestickmodelmapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24QVCandlestickModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto QVCandlestickModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN24QVCandlestickModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QVCandlestickModelMapper",
        "timestampRowChanged",
        "",
        "openRowChanged",
        "highRowChanged",
        "lowRowChanged",
        "closeRowChanged",
        "firstSetColumnChanged",
        "lastSetColumnChanged",
        "timestampRow",
        "openRow",
        "highRow",
        "lowRow",
        "closeRow",
        "firstSetColumn",
        "lastSetColumn"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timestampRowChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openRowChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highRowChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lowRowChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeRowChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'firstSetColumnChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastSetColumnChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'timestampRow'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'openRow'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'highRow'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'lowRow'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'closeRow'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'firstSetColumn'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'lastSetColumn'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QVCandlestickModelMapper, qt_meta_tag_ZN24QVCandlestickModelMapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QVCandlestickModelMapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QCandlestickModelMapper::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QVCandlestickModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QVCandlestickModelMapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QVCandlestickModelMapperE_t>.metaTypes,
    nullptr
} };

void QVCandlestickModelMapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QVCandlestickModelMapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timestampRowChanged(); break;
        case 1: _t->openRowChanged(); break;
        case 2: _t->highRowChanged(); break;
        case 3: _t->lowRowChanged(); break;
        case 4: _t->closeRowChanged(); break;
        case 5: _t->firstSetColumnChanged(); break;
        case 6: _t->lastSetColumnChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QVCandlestickModelMapper::*)()>(_a, &QVCandlestickModelMapper::timestampRowChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVCandlestickModelMapper::*)()>(_a, &QVCandlestickModelMapper::openRowChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVCandlestickModelMapper::*)()>(_a, &QVCandlestickModelMapper::highRowChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVCandlestickModelMapper::*)()>(_a, &QVCandlestickModelMapper::lowRowChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVCandlestickModelMapper::*)()>(_a, &QVCandlestickModelMapper::closeRowChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVCandlestickModelMapper::*)()>(_a, &QVCandlestickModelMapper::firstSetColumnChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVCandlestickModelMapper::*)()>(_a, &QVCandlestickModelMapper::lastSetColumnChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->timestampRow(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->openRow(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->highRow(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->lowRow(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->closeRow(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->firstSetColumn(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->lastSetColumn(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTimestampRow(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setOpenRow(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setHighRow(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setLowRow(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setCloseRow(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setFirstSetColumn(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setLastSetColumn(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QVCandlestickModelMapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QVCandlestickModelMapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QVCandlestickModelMapperE_t>.strings))
        return static_cast<void*>(this);
    return QCandlestickModelMapper::qt_metacast(_clname);
}

int QVCandlestickModelMapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QCandlestickModelMapper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QVCandlestickModelMapper::timestampRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QVCandlestickModelMapper::openRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QVCandlestickModelMapper::highRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QVCandlestickModelMapper::lowRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QVCandlestickModelMapper::closeRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QVCandlestickModelMapper::firstSetColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QVCandlestickModelMapper::lastSetColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
