/****************************************************************************
** Meta object code from reading C++ file 'declarativechart_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/chartsqml2/declarativechart_p.h"
#include <QtCharts/qlegend.h>
#include "declarativemargins_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativechart_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DeclarativeChartE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeChart::qt_create_metaobjectdata<qt_meta_tag_ZN16DeclarativeChartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeChart",
        "QML.Element",
        "ChartView",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "axisLabelsChanged",
        "",
        "titleColorChanged",
        "QColor",
        "color",
        "backgroundColorChanged",
        "dropShadowEnabledChanged",
        "enabled",
        "marginsChanged",
        "plotAreaChanged",
        "QRectF",
        "plotArea",
        "seriesAdded",
        "QAbstractSeries*",
        "series",
        "seriesRemoved",
        "plotAreaColorChanged",
        "backgroundRoundnessChanged",
        "diameter",
        "localizeNumbersChanged",
        "localeChanged",
        "animationDurationChanged",
        "msecs",
        "animationEasingCurveChanged",
        "QEasingCurve",
        "curve",
        "needRender",
        "pendingRenderNodeMouseEventResponses",
        "handleAntialiasingChanged",
        "enable",
        "sceneChanged",
        "QList<QRectF>",
        "region",
        "renderScene",
        "changeMargins",
        "top",
        "bottom",
        "left",
        "right",
        "handleAxisXSet",
        "QAbstractAxis*",
        "axis",
        "handleAxisYSet",
        "handleAxisXTopSet",
        "handleAxisYRightSet",
        "handleSeriesAdded",
        "handlePendingRenderNodeMouseEventResponses",
        "index",
        "seriesName",
        "createSeries",
        "type",
        "name",
        "axisX",
        "axisY",
        "removeSeries",
        "removeAllSeries",
        "setAxisX",
        "setAxisY",
        "zoom",
        "factor",
        "zoomIn",
        "rectangle",
        "zoomOut",
        "zoomReset",
        "isZoomed",
        "scrollLeft",
        "pixels",
        "scrollRight",
        "scrollUp",
        "scrollDown",
        "mapToValue",
        "QPointF",
        "position",
        "mapToPosition",
        "value",
        "theme",
        "Theme",
        "animationOptions",
        "Animation",
        "animationDuration",
        "animationEasingCurve",
        "title",
        "titleFont",
        "QFont",
        "titleColor",
        "legend",
        "QLegend*",
        "count",
        "backgroundColor",
        "dropShadowEnabled",
        "backgroundRoundness",
        "margins",
        "DeclarativeMargins*",
        "plotAreaColor",
        "axes",
        "QQmlListProperty<QAbstractAxis>",
        "localizeNumbers",
        "locale",
        "ChartThemeLight",
        "ChartThemeBlueCerulean",
        "ChartThemeDark",
        "ChartThemeBrownSand",
        "ChartThemeBlueNcs",
        "ChartThemeHighContrast",
        "ChartThemeBlueIcy",
        "ChartThemeQt",
        "NoAnimation",
        "GridAxisAnimations",
        "SeriesAnimations",
        "AllAnimations",
        "SeriesType",
        "SeriesTypeLine",
        "SeriesTypeArea",
        "SeriesTypeBar",
        "SeriesTypeStackedBar",
        "SeriesTypePercentBar",
        "SeriesTypePie",
        "SeriesTypeScatter",
        "SeriesTypeSpline",
        "SeriesTypeHorizontalBar",
        "SeriesTypeHorizontalStackedBar",
        "SeriesTypeHorizontalPercentBar",
        "SeriesTypeBoxPlot",
        "SeriesTypeCandlestick"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisLabelsChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(9, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dropShadowEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'marginsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(15, 8, QMC::AccessPublic, 0x102, QMetaType::Void),
        // Signal 'plotAreaChanged'
        QtMocHelpers::SignalData<void(QRectF)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'seriesAdded'
        QtMocHelpers::SignalData<void(QAbstractSeries *)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'seriesRemoved'
        QtMocHelpers::SignalData<void(QAbstractSeries *)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'plotAreaColorChanged'
        QtMocHelpers::RevisionedSignalData<void()>(23, 8, QMC::AccessPublic, 0x103, QMetaType::Void),
        // Signal 'backgroundRoundnessChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(24, 8, QMC::AccessPublic, 0x103, QMetaType::Void, {{
            { QMetaType::QReal, 25 },
        }}),
        // Signal 'localizeNumbersChanged'
        QtMocHelpers::RevisionedSignalData<void()>(26, 8, QMC::AccessPublic, 0x200, QMetaType::Void),
        // Signal 'localeChanged'
        QtMocHelpers::RevisionedSignalData<void()>(27, 8, QMC::AccessPublic, 0x200, QMetaType::Void),
        // Signal 'animationDurationChanged'
        QtMocHelpers::RevisionedSignalData<void(int)>(28, 8, QMC::AccessPublic, 0x201, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'animationEasingCurveChanged'
        QtMocHelpers::RevisionedSignalData<void(QEasingCurve)>(30, 8, QMC::AccessPublic, 0x201, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Signal 'needRender'
        QtMocHelpers::SignalData<void()>(33, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pendingRenderNodeMouseEventResponses'
        QtMocHelpers::SignalData<void()>(34, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleAntialiasingChanged'
        QtMocHelpers::SlotData<void(bool)>(35, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Slot 'sceneChanged'
        QtMocHelpers::SlotData<void(const QList<QRectF> &)>(37, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'renderScene'
        QtMocHelpers::SlotData<void()>(40, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeMargins'
        QtMocHelpers::SlotData<void(int, int, int, int)>(41, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 42 }, { QMetaType::Int, 43 }, { QMetaType::Int, 44 }, { QMetaType::Int, 45 },
        }}),
        // Slot 'handleAxisXSet'
        QtMocHelpers::SlotData<void(QAbstractAxis *)>(46, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'handleAxisYSet'
        QtMocHelpers::SlotData<void(QAbstractAxis *)>(49, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'handleAxisXTopSet'
        QtMocHelpers::SlotData<void(QAbstractAxis *)>(50, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'handleAxisYRightSet'
        QtMocHelpers::SlotData<void(QAbstractAxis *)>(51, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Slot 'handleSeriesAdded'
        QtMocHelpers::SlotData<void(QAbstractSeries *)>(52, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'handlePendingRenderNodeMouseEventResponses'
        QtMocHelpers::SlotData<void()>(53, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'series'
        QtMocHelpers::MethodData<QAbstractSeries *(int)>(21, 8, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Int, 54 },
        }}),
        // Method 'series'
        QtMocHelpers::MethodData<QAbstractSeries *(QString)>(21, 8, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 55 },
        }}),
        // Method 'createSeries'
        QtMocHelpers::MethodData<QAbstractSeries *(int, QString, QAbstractAxis *, QAbstractAxis *)>(56, 8, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Int, 57 }, { QMetaType::QString, 58 }, { 0x80000000 | 47, 59 }, { 0x80000000 | 47, 60 },
        }}),
        // Method 'createSeries'
        QtMocHelpers::MethodData<QAbstractSeries *(int, QString, QAbstractAxis *)>(56, 8, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 20, {{
            { QMetaType::Int, 57 }, { QMetaType::QString, 58 }, { 0x80000000 | 47, 59 },
        }}),
        // Method 'createSeries'
        QtMocHelpers::MethodData<QAbstractSeries *(int, QString)>(56, 8, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 20, {{
            { QMetaType::Int, 57 }, { QMetaType::QString, 58 },
        }}),
        // Method 'createSeries'
        QtMocHelpers::MethodData<QAbstractSeries *(int)>(56, 8, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 20, {{
            { QMetaType::Int, 57 },
        }}),
        // Method 'removeSeries'
        QtMocHelpers::MethodData<void(QAbstractSeries *)>(61, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'removeAllSeries'
        QtMocHelpers::MethodData<void()>(62, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'setAxisX'
        QtMocHelpers::MethodData<void(QAbstractAxis *, QAbstractSeries *)>(63, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 }, { 0x80000000 | 20, 21 },
        }}),
        // Method 'setAxisX'
        QtMocHelpers::MethodData<void(QAbstractAxis *)>(63, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Method 'setAxisY'
        QtMocHelpers::MethodData<void(QAbstractAxis *, QAbstractSeries *)>(64, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 }, { 0x80000000 | 20, 21 },
        }}),
        // Method 'setAxisY'
        QtMocHelpers::MethodData<void(QAbstractAxis *)>(64, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Method 'axisX'
        QtMocHelpers::MethodData<QAbstractAxis *(QAbstractSeries *)>(59, 8, QMC::AccessPublic, 0x80000000 | 47, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'axisX'
        QtMocHelpers::MethodData<QAbstractAxis *()>(59, 8, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 47),
        // Method 'axisY'
        QtMocHelpers::MethodData<QAbstractAxis *(QAbstractSeries *)>(60, 8, QMC::AccessPublic, 0x80000000 | 47, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'axisY'
        QtMocHelpers::MethodData<QAbstractAxis *()>(60, 8, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 47),
        // Method 'zoom'
        QtMocHelpers::MethodData<void(qreal)>(65, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 66 },
        }}),
        // Method 'zoomIn'
        QtMocHelpers::RevisionedMethodData<void()>(67, 8, QMC::AccessPublic, 0x201, QMetaType::Void),
        // Method 'zoomIn'
        QtMocHelpers::RevisionedMethodData<void(const QRectF &)>(67, 8, QMC::AccessPublic, 0x201, QMetaType::Void, {{
            { 0x80000000 | 17, 68 },
        }}),
        // Method 'zoomOut'
        QtMocHelpers::RevisionedMethodData<void()>(69, 8, QMC::AccessPublic, 0x201, QMetaType::Void),
        // Method 'zoomReset'
        QtMocHelpers::RevisionedMethodData<void()>(70, 8, QMC::AccessPublic, 0x201, QMetaType::Void),
        // Method 'isZoomed'
        QtMocHelpers::RevisionedMethodData<bool()>(71, 8, QMC::AccessPublic, 0x201, QMetaType::Bool),
        // Method 'scrollLeft'
        QtMocHelpers::MethodData<void(qreal)>(72, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 73 },
        }}),
        // Method 'scrollRight'
        QtMocHelpers::MethodData<void(qreal)>(74, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 73 },
        }}),
        // Method 'scrollUp'
        QtMocHelpers::MethodData<void(qreal)>(75, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 73 },
        }}),
        // Method 'scrollDown'
        QtMocHelpers::MethodData<void(qreal)>(76, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 73 },
        }}),
        // Method 'mapToValue'
        QtMocHelpers::RevisionedMethodData<QPointF(const QPointF &, QAbstractSeries *)>(77, 8, QMC::AccessPublic, 0x201, 0x80000000 | 78, {{
            { 0x80000000 | 78, 79 }, { 0x80000000 | 20, 21 },
        }}),
        // Method 'mapToValue'
        QtMocHelpers::RevisionedMethodData<QPointF(const QPointF &)>(77, 8, QMC::AccessPublic | QMC::MethodCloned, 0x201, 0x80000000 | 78, {{
            { 0x80000000 | 78, 79 },
        }}),
        // Method 'mapToPosition'
        QtMocHelpers::RevisionedMethodData<QPointF(const QPointF &, QAbstractSeries *)>(80, 8, QMC::AccessPublic, 0x201, 0x80000000 | 78, {{
            { 0x80000000 | 78, 81 }, { 0x80000000 | 20, 21 },
        }}),
        // Method 'mapToPosition'
        QtMocHelpers::RevisionedMethodData<QPointF(const QPointF &)>(80, 8, QMC::AccessPublic | QMC::MethodCloned, 0x201, 0x80000000 | 78, {{
            { 0x80000000 | 78, 81 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'theme'
        QtMocHelpers::PropertyData<enum Theme>(82, 0x80000000 | 83, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'animationOptions'
        QtMocHelpers::PropertyData<enum Animation>(84, 0x80000000 | 85, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'animationDuration'
        QtMocHelpers::PropertyData<int>(86, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12, 0x201),
        // property 'animationEasingCurve'
        QtMocHelpers::PropertyData<QEasingCurve>(87, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13, 0x201),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(88, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'titleFont'
        QtMocHelpers::PropertyData<QFont>(89, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'titleColor'
        QtMocHelpers::PropertyData<QColor>(91, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'legend'
        QtMocHelpers::PropertyData<QLegend*>(92, 0x80000000 | 93, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'count'
        QtMocHelpers::PropertyData<int>(94, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(95, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'dropShadowEnabled'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'backgroundRoundness'
        QtMocHelpers::PropertyData<qreal>(97, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9, 0x103),
        // property 'margins'
        QtMocHelpers::PropertyData<DeclarativeMargins*>(98, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4, 0x102),
        // property 'plotArea'
        QtMocHelpers::PropertyData<QRectF>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5, 0x101),
        // property 'plotAreaColor'
        QtMocHelpers::PropertyData<QColor>(100, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8, 0x103),
        // property 'axes'
        QtMocHelpers::PropertyData<QQmlListProperty<QAbstractAxis>>(101, 0x80000000 | 102, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, -1, 0x102),
        // property 'localizeNumbers'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10, 0x200),
        // property 'locale'
        QtMocHelpers::PropertyData<QLocale>(104, QMetaType::QLocale, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11, 0x200),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Theme'
        QtMocHelpers::EnumData<enum Theme>(83, 83, QMC::EnumFlags{}).add({
            {  105, Theme::ChartThemeLight },
            {  106, Theme::ChartThemeBlueCerulean },
            {  107, Theme::ChartThemeDark },
            {  108, Theme::ChartThemeBrownSand },
            {  109, Theme::ChartThemeBlueNcs },
            {  110, Theme::ChartThemeHighContrast },
            {  111, Theme::ChartThemeBlueIcy },
            {  112, Theme::ChartThemeQt },
        }),
        // enum 'Animation'
        QtMocHelpers::EnumData<enum Animation>(85, 85, QMC::EnumFlags{}).add({
            {  113, Animation::NoAnimation },
            {  114, Animation::GridAxisAnimations },
            {  115, Animation::SeriesAnimations },
            {  116, Animation::AllAnimations },
        }),
        // enum 'SeriesType'
        QtMocHelpers::EnumData<enum SeriesType>(117, 117, QMC::EnumFlags{}).add({
            {  118, SeriesType::SeriesTypeLine },
            {  119, SeriesType::SeriesTypeArea },
            {  120, SeriesType::SeriesTypeBar },
            {  121, SeriesType::SeriesTypeStackedBar },
            {  122, SeriesType::SeriesTypePercentBar },
            {  123, SeriesType::SeriesTypePie },
            {  124, SeriesType::SeriesTypeScatter },
            {  125, SeriesType::SeriesTypeSpline },
            {  126, SeriesType::SeriesTypeHorizontalBar },
            {  127, SeriesType::SeriesTypeHorizontalStackedBar },
            {  128, SeriesType::SeriesTypeHorizontalPercentBar },
            {  129, SeriesType::SeriesTypeBoxPlot },
            {  130, SeriesType::SeriesTypeCandlestick },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeChart, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeChart::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DeclarativeChartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DeclarativeChartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DeclarativeChartE_t>.metaTypes,
    nullptr
} };

void DeclarativeChart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeChart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisLabelsChanged(); break;
        case 1: _t->titleColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 2: _t->backgroundColorChanged(); break;
        case 3: _t->dropShadowEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->marginsChanged(); break;
        case 5: _t->plotAreaChanged((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 6: _t->seriesAdded((*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[1]))); break;
        case 7: _t->seriesRemoved((*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[1]))); break;
        case 8: _t->plotAreaColorChanged(); break;
        case 9: _t->backgroundRoundnessChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 10: _t->localizeNumbersChanged(); break;
        case 11: _t->localeChanged(); break;
        case 12: _t->animationDurationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->animationEasingCurveChanged((*reinterpret_cast<std::add_pointer_t<QEasingCurve>>(_a[1]))); break;
        case 14: _t->needRender(); break;
        case 15: _t->pendingRenderNodeMouseEventResponses(); break;
        case 16: _t->handleAntialiasingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->sceneChanged((*reinterpret_cast<std::add_pointer_t<QList<QRectF>>>(_a[1]))); break;
        case 18: _t->renderScene(); break;
        case 19: _t->changeMargins((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 20: _t->handleAxisXSet((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 21: _t->handleAxisYSet((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 22: _t->handleAxisXTopSet((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 23: _t->handleAxisYRightSet((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 24: _t->handleSeriesAdded((*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[1]))); break;
        case 25: _t->handlePendingRenderNodeMouseEventResponses(); break;
        case 26: { QAbstractSeries* _r = _t->series((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 27: { QAbstractSeries* _r = _t->series((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 28: { QAbstractSeries* _r = _t->createSeries((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 29: { QAbstractSeries* _r = _t->createSeries((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 30: { QAbstractSeries* _r = _t->createSeries((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 31: { QAbstractSeries* _r = _t->createSeries((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 32: _t->removeSeries((*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[1]))); break;
        case 33: _t->removeAllSeries(); break;
        case 34: _t->setAxisX((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[2]))); break;
        case 35: _t->setAxisX((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 36: _t->setAxisY((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[2]))); break;
        case 37: _t->setAxisY((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 38: { QAbstractAxis* _r = _t->axisX((*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAbstractAxis**>(_a[0]) = std::move(_r); }  break;
        case 39: { QAbstractAxis* _r = _t->axisX();
            if (_a[0]) *reinterpret_cast<QAbstractAxis**>(_a[0]) = std::move(_r); }  break;
        case 40: { QAbstractAxis* _r = _t->axisY((*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAbstractAxis**>(_a[0]) = std::move(_r); }  break;
        case 41: { QAbstractAxis* _r = _t->axisY();
            if (_a[0]) *reinterpret_cast<QAbstractAxis**>(_a[0]) = std::move(_r); }  break;
        case 42: _t->zoom((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 43: _t->zoomIn(); break;
        case 44: _t->zoomIn((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 45: _t->zoomOut(); break;
        case 46: _t->zoomReset(); break;
        case 47: { bool _r = _t->isZoomed();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->scrollLeft((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 49: _t->scrollRight((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 50: _t->scrollUp((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 51: _t->scrollDown((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 52: { QPointF _r = _t->mapToValue((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 53: { QPointF _r = _t->mapToValue((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 54: { QPointF _r = _t->mapToPosition((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractSeries*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        case 55: { QPointF _r = _t->mapToPosition((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPointF*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        case 54:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSeries* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)()>(_a, &DeclarativeChart::axisLabelsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)(QColor )>(_a, &DeclarativeChart::titleColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)()>(_a, &DeclarativeChart::backgroundColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)(bool )>(_a, &DeclarativeChart::dropShadowEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)()>(_a, &DeclarativeChart::marginsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)(QRectF )>(_a, &DeclarativeChart::plotAreaChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)(QAbstractSeries * )>(_a, &DeclarativeChart::seriesAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)(QAbstractSeries * )>(_a, &DeclarativeChart::seriesRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)()>(_a, &DeclarativeChart::plotAreaColorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)(qreal )>(_a, &DeclarativeChart::backgroundRoundnessChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)()>(_a, &DeclarativeChart::localizeNumbersChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)()>(_a, &DeclarativeChart::localeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)(int )>(_a, &DeclarativeChart::animationDurationChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)(QEasingCurve )>(_a, &DeclarativeChart::animationEasingCurveChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)()>(_a, &DeclarativeChart::needRender, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeChart::*)()>(_a, &DeclarativeChart::pendingRenderNodeMouseEventResponses, 15))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QLegend* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Theme*>(_v) = _t->theme(); break;
        case 1: *reinterpret_cast<enum Animation*>(_v) = _t->animationOptions(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->animationDuration(); break;
        case 3: *reinterpret_cast<QEasingCurve*>(_v) = _t->animationEasingCurve(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 5: *reinterpret_cast<QFont*>(_v) = _t->titleFont(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->titleColor(); break;
        case 7: *reinterpret_cast<QLegend**>(_v) = _t->legend(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->dropShadowEnabled(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->backgroundRoundness(); break;
        case 12: *reinterpret_cast<DeclarativeMargins**>(_v) = _t->margins(); break;
        case 13: *reinterpret_cast<QRectF*>(_v) = _t->plotArea(); break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->plotAreaColor(); break;
        case 15: *reinterpret_cast<QQmlListProperty<QAbstractAxis>*>(_v) = _t->axes(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->localizeNumbers(); break;
        case 17: *reinterpret_cast<QLocale*>(_v) = _t->locale(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTheme(*reinterpret_cast<enum Theme*>(_v)); break;
        case 1: _t->setAnimationOptions(*reinterpret_cast<enum Animation*>(_v)); break;
        case 2: _t->setAnimationDuration(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setAnimationEasingCurve(*reinterpret_cast<QEasingCurve*>(_v)); break;
        case 4: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setTitleFont(*reinterpret_cast<QFont*>(_v)); break;
        case 6: _t->setTitleColor(*reinterpret_cast<QColor*>(_v)); break;
        case 9: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 10: _t->setDropShadowEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setBackgroundRoundness(*reinterpret_cast<qreal*>(_v)); break;
        case 13: _t->setPlotArea(*reinterpret_cast<QRectF*>(_v)); break;
        case 14: _t->setPlotAreaColor(*reinterpret_cast<QColor*>(_v)); break;
        case 16: _t->setLocalizeNumbers(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setLocale(*reinterpret_cast<QLocale*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeChart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeChart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DeclarativeChartE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int DeclarativeChart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeChart::axisLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DeclarativeChart::titleColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeChart::backgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DeclarativeChart::dropShadowEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeclarativeChart::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DeclarativeChart::plotAreaChanged(QRectF _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeclarativeChart::seriesAdded(QAbstractSeries * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DeclarativeChart::seriesRemoved(QAbstractSeries * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DeclarativeChart::plotAreaColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DeclarativeChart::backgroundRoundnessChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DeclarativeChart::localizeNumbersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DeclarativeChart::localeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DeclarativeChart::animationDurationChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DeclarativeChart::animationEasingCurveChanged(QEasingCurve _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DeclarativeChart::needRender()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DeclarativeChart::pendingRenderNodeMouseEventResponses()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
