/****************************************************************************
** Meta object code from reading C++ file 'qcandlestickset.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/candlestickchart/qcandlestickset.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qcandlestickset.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QCandlestickSetE_t {};
} // unnamed namespace

template <> constexpr inline auto QCandlestickSet::qt_create_metaobjectdata<qt_meta_tag_ZN15QCandlestickSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCandlestickSet",
        "clicked",
        "",
        "hovered",
        "status",
        "pressed",
        "released",
        "doubleClicked",
        "timestampChanged",
        "openChanged",
        "highChanged",
        "lowChanged",
        "closeChanged",
        "brushChanged",
        "penChanged",
        "timestamp",
        "open",
        "high",
        "low",
        "close",
        "brush",
        "QBrush",
        "pen",
        "QPen"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hovered'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'pressed'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'released'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timestampChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lowChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brushChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'penChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'timestamp'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'open'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'high'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'low'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'close'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'brush'
        QtMocHelpers::PropertyData<QBrush>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'pen'
        QtMocHelpers::PropertyData<QPen>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QCandlestickSet, qt_meta_tag_ZN15QCandlestickSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCandlestickSet::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QCandlestickSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QCandlestickSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QCandlestickSetE_t>.metaTypes,
    nullptr
} };

void QCandlestickSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QCandlestickSet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->hovered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->pressed(); break;
        case 3: _t->released(); break;
        case 4: _t->doubleClicked(); break;
        case 5: _t->timestampChanged(); break;
        case 6: _t->openChanged(); break;
        case 7: _t->highChanged(); break;
        case 8: _t->lowChanged(); break;
        case 9: _t->closeChanged(); break;
        case 10: _t->brushChanged(); break;
        case 11: _t->penChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::clicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)(bool )>(_a, &QCandlestickSet::hovered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::pressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::released, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::doubleClicked, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::timestampChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::openChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::highChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::lowChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::closeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::brushChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickSet::*)()>(_a, &QCandlestickSet::penChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->timestamp(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->open(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->high(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->low(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->close(); break;
        case 5: *reinterpret_cast<QBrush*>(_v) = _t->brush(); break;
        case 6: *reinterpret_cast<QPen*>(_v) = _t->pen(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTimestamp(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setOpen(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setHigh(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setLow(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setClose(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setBrush(*reinterpret_cast<QBrush*>(_v)); break;
        case 6: _t->setPen(*reinterpret_cast<QPen*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QCandlestickSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCandlestickSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QCandlestickSetE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QCandlestickSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QCandlestickSet::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QCandlestickSet::hovered(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QCandlestickSet::pressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QCandlestickSet::released()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QCandlestickSet::doubleClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QCandlestickSet::timestampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QCandlestickSet::openChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QCandlestickSet::highChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QCandlestickSet::lowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QCandlestickSet::closeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QCandlestickSet::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QCandlestickSet::penChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
