/****************************************************************************
** Meta object code from reading C++ file 'qchart.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/qchart.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qchart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6QChartE_t {};
} // unnamed namespace

template <> constexpr inline auto QChart::qt_create_metaobjectdata<qt_meta_tag_ZN6QChartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QChart",
        "plotAreaChanged",
        "",
        "QRectF",
        "plotArea",
        "theme",
        "QChart::ChartTheme",
        "title",
        "backgroundVisible",
        "dropShadowEnabled",
        "backgroundRoundness",
        "animationOptions",
        "QChart::AnimationOptions",
        "animationDuration",
        "animationEasingCurve",
        "QEasingCurve",
        "margins",
        "QMargins",
        "chartType",
        "QChart::ChartType",
        "plotAreaBackgroundVisible",
        "localizeNumbers",
        "locale",
        "ChartType",
        "ChartTypeUndefined",
        "ChartTypeCartesian",
        "ChartTypePolar",
        "ChartTheme",
        "ChartThemeLight",
        "ChartThemeBlueCerulean",
        "ChartThemeDark",
        "ChartThemeBrownSand",
        "ChartThemeBlueNcs",
        "ChartThemeHighContrast",
        "ChartThemeBlueIcy",
        "ChartThemeQt",
        "AnimationOption",
        "NoAnimation",
        "GridAxisAnimations",
        "SeriesAnimations",
        "AllAnimations"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'plotAreaChanged'
        QtMocHelpers::SignalData<void(const QRectF &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'theme'
        QtMocHelpers::PropertyData<QChart::ChartTheme>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'backgroundVisible'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'dropShadowEnabled'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'backgroundRoundness'
        QtMocHelpers::PropertyData<qreal>(10, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'animationOptions'
        QtMocHelpers::PropertyData<QChart::AnimationOptions>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'animationDuration'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'animationEasingCurve'
        QtMocHelpers::PropertyData<QEasingCurve>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'margins'
        QtMocHelpers::PropertyData<QMargins>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'chartType'
        QtMocHelpers::PropertyData<QChart::ChartType>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'plotAreaBackgroundVisible'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'localizeNumbers'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'locale'
        QtMocHelpers::PropertyData<QLocale>(22, QMetaType::QLocale, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'plotArea'
        QtMocHelpers::PropertyData<QRectF>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ChartType'
        QtMocHelpers::EnumData<enum ChartType>(23, 23, QMC::EnumFlags{}).add({
            {   24, ChartType::ChartTypeUndefined },
            {   25, ChartType::ChartTypeCartesian },
            {   26, ChartType::ChartTypePolar },
        }),
        // enum 'ChartTheme'
        QtMocHelpers::EnumData<enum ChartTheme>(27, 27, QMC::EnumFlags{}).add({
            {   28, ChartTheme::ChartThemeLight },
            {   29, ChartTheme::ChartThemeBlueCerulean },
            {   30, ChartTheme::ChartThemeDark },
            {   31, ChartTheme::ChartThemeBrownSand },
            {   32, ChartTheme::ChartThemeBlueNcs },
            {   33, ChartTheme::ChartThemeHighContrast },
            {   34, ChartTheme::ChartThemeBlueIcy },
            {   35, ChartTheme::ChartThemeQt },
        }),
        // enum 'AnimationOption'
        QtMocHelpers::EnumData<enum AnimationOption>(36, 36, QMC::EnumFlags{}).add({
            {   37, AnimationOption::NoAnimation },
            {   38, AnimationOption::GridAxisAnimations },
            {   39, AnimationOption::SeriesAnimations },
            {   40, AnimationOption::AllAnimations },
        }),
    };
    return QtMocHelpers::metaObjectData<QChart, qt_meta_tag_ZN6QChartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QChart::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6QChartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6QChartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6QChartE_t>.metaTypes,
    nullptr
} };

void QChart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QChart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->plotAreaChanged((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QChart::*)(const QRectF & )>(_a, &QChart::plotAreaChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QChart::ChartTheme*>(_v) = _t->theme(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isBackgroundVisible(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isDropShadowEnabled(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->backgroundRoundness(); break;
        case 5: *reinterpret_cast<QChart::AnimationOptions*>(_v) = _t->animationOptions(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->animationDuration(); break;
        case 7: *reinterpret_cast<QEasingCurve*>(_v) = _t->animationEasingCurve(); break;
        case 8: *reinterpret_cast<QMargins*>(_v) = _t->margins(); break;
        case 9: *reinterpret_cast<QChart::ChartType*>(_v) = _t->chartType(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isPlotAreaBackgroundVisible(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->localizeNumbers(); break;
        case 12: *reinterpret_cast<QLocale*>(_v) = _t->locale(); break;
        case 13: *reinterpret_cast<QRectF*>(_v) = _t->plotArea(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTheme(*reinterpret_cast<QChart::ChartTheme*>(_v)); break;
        case 1: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setBackgroundVisible(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setDropShadowEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setBackgroundRoundness(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setAnimationOptions(*reinterpret_cast<QChart::AnimationOptions*>(_v)); break;
        case 6: _t->setAnimationDuration(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setAnimationEasingCurve(*reinterpret_cast<QEasingCurve*>(_v)); break;
        case 8: _t->setMargins(*reinterpret_cast<QMargins*>(_v)); break;
        case 10: _t->setPlotAreaBackgroundVisible(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setLocalizeNumbers(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setLocale(*reinterpret_cast<QLocale*>(_v)); break;
        case 13: _t->setPlotArea(*reinterpret_cast<QRectF*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QChart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QChart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6QChartE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsWidget::qt_metacast(_clname);
}

int QChart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void QChart::plotAreaChanged(const QRectF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
