/****************************************************************************
** Meta object code from reading C++ file 'qcategoryaxis.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/axis/categoryaxis/qcategoryaxis.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qcategoryaxis.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QCategoryAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto QCategoryAxis::qt_create_metaobjectdata<qt_meta_tag_ZN13QCategoryAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCategoryAxis",
        "categoriesChanged",
        "",
        "labelsPositionChanged",
        "QCategoryAxis::AxisLabelsPosition",
        "position",
        "startValue",
        "count",
        "categoriesLabels",
        "labelsPosition",
        "AxisLabelsPosition",
        "AxisLabelsPositionCenter",
        "AxisLabelsPositionOnValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'categoriesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelsPositionChanged'
        QtMocHelpers::SignalData<void(QCategoryAxis::AxisLabelsPosition)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'startValue'
        QtMocHelpers::PropertyData<qreal>(6, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'count'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'categoriesLabels'
        QtMocHelpers::PropertyData<QStringList>(8, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'labelsPosition'
        QtMocHelpers::PropertyData<enum AxisLabelsPosition>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AxisLabelsPosition'
        QtMocHelpers::EnumData<enum AxisLabelsPosition>(10, 10, QMC::EnumFlags{}).add({
            {   11, AxisLabelsPosition::AxisLabelsPositionCenter },
            {   12, AxisLabelsPosition::AxisLabelsPositionOnValue },
        }),
    };
    return QtMocHelpers::metaObjectData<QCategoryAxis, qt_meta_tag_ZN13QCategoryAxisE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCategoryAxis::staticMetaObject = { {
    QMetaObject::SuperData::link<QValueAxis::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QCategoryAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QCategoryAxisE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QCategoryAxisE_t>.metaTypes,
    nullptr
} };

void QCategoryAxis::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QCategoryAxis *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->categoriesChanged(); break;
        case 1: _t->labelsPositionChanged((*reinterpret_cast<std::add_pointer_t<QCategoryAxis::AxisLabelsPosition>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QCategoryAxis::*)()>(_a, &QCategoryAxis::categoriesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCategoryAxis::*)(QCategoryAxis::AxisLabelsPosition )>(_a, &QCategoryAxis::labelsPositionChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->startValue(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->categoriesLabels(); break;
        case 3: *reinterpret_cast<enum AxisLabelsPosition*>(_v) = _t->labelsPosition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setStartValue(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setLabelsPosition(*reinterpret_cast<enum AxisLabelsPosition*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QCategoryAxis::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCategoryAxis::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QCategoryAxisE_t>.strings))
        return static_cast<void*>(this);
    return QValueAxis::qt_metacast(_clname);
}

int QCategoryAxis::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QValueAxis::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QCategoryAxis::categoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QCategoryAxis::labelsPositionChanged(QCategoryAxis::AxisLabelsPosition _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
