/****************************************************************************
** Meta object code from reading C++ file 'qabstractseries.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/qabstractseries.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qabstractseries.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QAbstractSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto QAbstractSeries::qt_create_metaobjectdata<qt_meta_tag_ZN15QAbstractSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QAbstractSeries",
        "nameChanged",
        "",
        "visibleChanged",
        "opacityChanged",
        "useOpenGLChanged",
        "name",
        "visible",
        "opacity",
        "type",
        "SeriesType",
        "useOpenGL",
        "SeriesTypeLine",
        "SeriesTypeArea",
        "SeriesTypeBar",
        "SeriesTypeStackedBar",
        "SeriesTypePercentBar",
        "SeriesTypePie",
        "SeriesTypeScatter",
        "SeriesTypeSpline",
        "SeriesTypeHorizontalBar",
        "SeriesTypeHorizontalStackedBar",
        "SeriesTypeHorizontalPercentBar",
        "SeriesTypeBoxPlot",
        "SeriesTypeCandlestick"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useOpenGLChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'opacity'
        QtMocHelpers::PropertyData<qreal>(8, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'type'
        QtMocHelpers::PropertyData<enum SeriesType>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'useOpenGL'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SeriesType'
        QtMocHelpers::EnumData<enum SeriesType>(10, 10, QMC::EnumFlags{}).add({
            {   12, SeriesType::SeriesTypeLine },
            {   13, SeriesType::SeriesTypeArea },
            {   14, SeriesType::SeriesTypeBar },
            {   15, SeriesType::SeriesTypeStackedBar },
            {   16, SeriesType::SeriesTypePercentBar },
            {   17, SeriesType::SeriesTypePie },
            {   18, SeriesType::SeriesTypeScatter },
            {   19, SeriesType::SeriesTypeSpline },
            {   20, SeriesType::SeriesTypeHorizontalBar },
            {   21, SeriesType::SeriesTypeHorizontalStackedBar },
            {   22, SeriesType::SeriesTypeHorizontalPercentBar },
            {   23, SeriesType::SeriesTypeBoxPlot },
            {   24, SeriesType::SeriesTypeCandlestick },
        }),
    };
    return QtMocHelpers::metaObjectData<QAbstractSeries, qt_meta_tag_ZN15QAbstractSeriesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QAbstractSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QAbstractSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QAbstractSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QAbstractSeriesE_t>.metaTypes,
    nullptr
} };

void QAbstractSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QAbstractSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->visibleChanged(); break;
        case 2: _t->opacityChanged(); break;
        case 3: _t->useOpenGLChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QAbstractSeries::*)()>(_a, &QAbstractSeries::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractSeries::*)()>(_a, &QAbstractSeries::visibleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractSeries::*)()>(_a, &QAbstractSeries::opacityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractSeries::*)()>(_a, &QAbstractSeries::useOpenGLChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isVisible(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->opacity(); break;
        case 3: *reinterpret_cast<enum SeriesType*>(_v) = _t->type(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->useOpenGL(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setOpacity(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setUseOpenGL(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QAbstractSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QAbstractSeriesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QAbstractSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QAbstractSeries::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QAbstractSeries::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QAbstractSeries::opacityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QAbstractSeries::useOpenGLChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
