/****************************************************************************
** Meta object code from reading C++ file 'qboxplotseries.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/boxplotchart/qboxplotseries.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qboxplotseries.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14QBoxPlotSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto QBoxPlotSeries::qt_create_metaobjectdata<qt_meta_tag_ZN14QBoxPlotSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QBoxPlotSeries",
        "clicked",
        "",
        "QBoxSet*",
        "boxset",
        "hovered",
        "status",
        "pressed",
        "released",
        "doubleClicked",
        "countChanged",
        "penChanged",
        "brushChanged",
        "boxOutlineVisibilityChanged",
        "boxWidthChanged",
        "boxsetsAdded",
        "QList<QBoxSet*>",
        "sets",
        "boxsetsRemoved",
        "boxOutlineVisible",
        "boxWidth",
        "pen",
        "QPen",
        "brush",
        "QBrush",
        "count"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void(QBoxSet *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'hovered'
        QtMocHelpers::SignalData<void(bool, QBoxSet *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'pressed'
        QtMocHelpers::SignalData<void(QBoxSet *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'released'
        QtMocHelpers::SignalData<void(QBoxSet *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void(QBoxSet *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'penChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brushChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boxOutlineVisibilityChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boxWidthChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boxsetsAdded'
        QtMocHelpers::SignalData<void(const QList<QBoxSet*> &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'boxsetsRemoved'
        QtMocHelpers::SignalData<void(const QList<QBoxSet*> &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'boxOutlineVisible'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'boxWidth'
        QtMocHelpers::PropertyData<qreal>(20, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'pen'
        QtMocHelpers::PropertyData<QPen>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'brush'
        QtMocHelpers::PropertyData<QBrush>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'count'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags, 5, 0x200),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QBoxPlotSeries, qt_meta_tag_ZN14QBoxPlotSeriesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QBoxPlotSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QBoxPlotSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QBoxPlotSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14QBoxPlotSeriesE_t>.metaTypes,
    nullptr
} };

void QBoxPlotSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QBoxPlotSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast<std::add_pointer_t<QBoxSet*>>(_a[1]))); break;
        case 1: _t->hovered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QBoxSet*>>(_a[2]))); break;
        case 2: _t->pressed((*reinterpret_cast<std::add_pointer_t<QBoxSet*>>(_a[1]))); break;
        case 3: _t->released((*reinterpret_cast<std::add_pointer_t<QBoxSet*>>(_a[1]))); break;
        case 4: _t->doubleClicked((*reinterpret_cast<std::add_pointer_t<QBoxSet*>>(_a[1]))); break;
        case 5: _t->countChanged(); break;
        case 6: _t->penChanged(); break;
        case 7: _t->brushChanged(); break;
        case 8: _t->boxOutlineVisibilityChanged(); break;
        case 9: _t->boxWidthChanged(); break;
        case 10: _t->boxsetsAdded((*reinterpret_cast<std::add_pointer_t<QList<QBoxSet*>>>(_a[1]))); break;
        case 11: _t->boxsetsRemoved((*reinterpret_cast<std::add_pointer_t<QList<QBoxSet*>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBoxSet* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBoxSet* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBoxSet* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBoxSet* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBoxSet* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QBoxSet*> >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QBoxSet*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)(QBoxSet * )>(_a, &QBoxPlotSeries::clicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)(bool , QBoxSet * )>(_a, &QBoxPlotSeries::hovered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)(QBoxSet * )>(_a, &QBoxPlotSeries::pressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)(QBoxSet * )>(_a, &QBoxPlotSeries::released, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)(QBoxSet * )>(_a, &QBoxPlotSeries::doubleClicked, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)()>(_a, &QBoxPlotSeries::countChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)()>(_a, &QBoxPlotSeries::penChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)()>(_a, &QBoxPlotSeries::brushChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)()>(_a, &QBoxPlotSeries::boxOutlineVisibilityChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)()>(_a, &QBoxPlotSeries::boxWidthChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)(const QList<QBoxSet*> & )>(_a, &QBoxPlotSeries::boxsetsAdded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QBoxPlotSeries::*)(const QList<QBoxSet*> & )>(_a, &QBoxPlotSeries::boxsetsRemoved, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->boxOutlineVisible(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->boxWidth(); break;
        case 2: *reinterpret_cast<QPen*>(_v) = _t->pen(); break;
        case 3: *reinterpret_cast<QBrush*>(_v) = _t->brush(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->count(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBoxOutlineVisible(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setBoxWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setPen(*reinterpret_cast<QPen*>(_v)); break;
        case 3: _t->setBrush(*reinterpret_cast<QBrush*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QBoxPlotSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QBoxPlotSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QBoxPlotSeriesE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractSeries::qt_metacast(_clname);
}

int QBoxPlotSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QBoxPlotSeries::clicked(QBoxSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QBoxPlotSeries::hovered(bool _t1, QBoxSet * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void QBoxPlotSeries::pressed(QBoxSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QBoxPlotSeries::released(QBoxSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QBoxPlotSeries::doubleClicked(QBoxSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QBoxPlotSeries::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QBoxPlotSeries::penChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QBoxPlotSeries::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QBoxPlotSeries::boxOutlineVisibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QBoxPlotSeries::boxWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QBoxPlotSeries::boxsetsAdded(const QList<QBoxSet*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void QBoxPlotSeries::boxsetsRemoved(const QList<QBoxSet*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
