/****************************************************************************
** Meta object code from reading C++ file 'candlestick_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/candlestickchart/candlestick_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'candlestick_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11CandlestickE_t {};
} // unnamed namespace

template <> constexpr inline auto Candlestick::qt_create_metaobjectdata<qt_meta_tag_ZN11CandlestickE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Candlestick",
        "clicked",
        "",
        "QCandlestickSet*",
        "set",
        "hovered",
        "status",
        "pressed",
        "released",
        "doubleClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void(QCandlestickSet *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'hovered'
        QtMocHelpers::SignalData<void(bool, QCandlestickSet *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'pressed'
        QtMocHelpers::SignalData<void(QCandlestickSet *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'released'
        QtMocHelpers::SignalData<void(QCandlestickSet *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void(QCandlestickSet *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Candlestick, qt_meta_tag_ZN11CandlestickE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Candlestick::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CandlestickE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CandlestickE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11CandlestickE_t>.metaTypes,
    nullptr
} };

void Candlestick::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Candlestick *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast<std::add_pointer_t<QCandlestickSet*>>(_a[1]))); break;
        case 1: _t->hovered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QCandlestickSet*>>(_a[2]))); break;
        case 2: _t->pressed((*reinterpret_cast<std::add_pointer_t<QCandlestickSet*>>(_a[1]))); break;
        case 3: _t->released((*reinterpret_cast<std::add_pointer_t<QCandlestickSet*>>(_a[1]))); break;
        case 4: _t->doubleClicked((*reinterpret_cast<std::add_pointer_t<QCandlestickSet*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Candlestick::*)(QCandlestickSet * )>(_a, &Candlestick::clicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Candlestick::*)(bool , QCandlestickSet * )>(_a, &Candlestick::hovered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Candlestick::*)(QCandlestickSet * )>(_a, &Candlestick::pressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Candlestick::*)(QCandlestickSet * )>(_a, &Candlestick::released, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Candlestick::*)(QCandlestickSet * )>(_a, &Candlestick::doubleClicked, 4))
            return;
    }
}

const QMetaObject *Candlestick::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Candlestick::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11CandlestickE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsObject::qt_metacast(_clname);
}

int Candlestick::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Candlestick::clicked(QCandlestickSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Candlestick::hovered(bool _t1, QCandlestickSet * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Candlestick::pressed(QCandlestickSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Candlestick::released(QCandlestickSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Candlestick::doubleClicked(QCandlestickSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
