/****************************************************************************
** Meta object code from reading C++ file 'qvbarmodelmapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/barchart/qvbarmodelmapper.h"
#include <QtCharts/qabstractbarseries.h>
#include <QtCharts/qvbarmodelmapper.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvbarmodelmapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16QVBarModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto QVBarModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN16QVBarModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QVBarModelMapper",
        "seriesReplaced",
        "",
        "modelReplaced",
        "firstBarSetColumnChanged",
        "lastBarSetColumnChanged",
        "firstRowChanged",
        "rowCountChanged",
        "series",
        "QAbstractBarSeries*",
        "model",
        "QAbstractItemModel*",
        "firstBarSetColumn",
        "lastBarSetColumn",
        "firstRow",
        "rowCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'seriesReplaced'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelReplaced'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'firstBarSetColumnChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastBarSetColumnChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'firstRowChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rowCountChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'series'
        QtMocHelpers::PropertyData<QAbstractBarSeries*>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'model'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'firstBarSetColumn'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'lastBarSetColumn'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'firstRow'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'rowCount'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QVBarModelMapper, qt_meta_tag_ZN16QVBarModelMapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QVBarModelMapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QBarModelMapper::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QVBarModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QVBarModelMapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QVBarModelMapperE_t>.metaTypes,
    nullptr
} };

void QVBarModelMapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QVBarModelMapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->seriesReplaced(); break;
        case 1: _t->modelReplaced(); break;
        case 2: _t->firstBarSetColumnChanged(); break;
        case 3: _t->lastBarSetColumnChanged(); break;
        case 4: _t->firstRowChanged(); break;
        case 5: _t->rowCountChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QVBarModelMapper::*)()>(_a, &QVBarModelMapper::seriesReplaced, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVBarModelMapper::*)()>(_a, &QVBarModelMapper::modelReplaced, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVBarModelMapper::*)()>(_a, &QVBarModelMapper::firstBarSetColumnChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVBarModelMapper::*)()>(_a, &QVBarModelMapper::lastBarSetColumnChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVBarModelMapper::*)()>(_a, &QVBarModelMapper::firstRowChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QVBarModelMapper::*)()>(_a, &QVBarModelMapper::rowCountChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractBarSeries**>(_v) = _t->series(); break;
        case 1: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->model(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->firstBarSetColumn(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->lastBarSetColumn(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->firstRow(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSeries(*reinterpret_cast<QAbstractBarSeries**>(_v)); break;
        case 1: _t->setModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 2: _t->setFirstBarSetColumn(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setLastBarSetColumn(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setFirstRow(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setRowCount(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QVBarModelMapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QVBarModelMapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QVBarModelMapperE_t>.strings))
        return static_cast<void*>(this);
    return QBarModelMapper::qt_metacast(_clname);
}

int QVBarModelMapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QBarModelMapper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QVBarModelMapper::seriesReplaced()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QVBarModelMapper::modelReplaced()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QVBarModelMapper::firstBarSetColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QVBarModelMapper::lastBarSetColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QVBarModelMapper::firstRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QVBarModelMapper::rowCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
