/****************************************************************************
** Meta object code from reading C++ file 'qabstractbarseries_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/barchart/qabstractbarseries_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qabstractbarseries_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25QAbstractBarSeriesPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto QAbstractBarSeriesPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN25QAbstractBarSeriesPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QAbstractBarSeriesPrivate",
        "clicked",
        "",
        "index",
        "QBarSet*",
        "barset",
        "pressed",
        "released",
        "doubleClicked",
        "updatedBars",
        "updatedLayout",
        "restructuredBars",
        "labelsVisibleChanged",
        "visible",
        "visibleChanged",
        "setValueChanged",
        "setValueAdded",
        "count",
        "setValueRemoved",
        "handleSetValueChange",
        "handleSetValueAdd",
        "handleSetValueRemove"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void(int, QBarSet *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'pressed'
        QtMocHelpers::SignalData<void(int, QBarSet *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'released'
        QtMocHelpers::SignalData<void(int, QBarSet *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void(int, QBarSet *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'updatedBars'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatedLayout'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'restructuredBars'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelsVisibleChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setValueChanged'
        QtMocHelpers::SignalData<void(int, QBarSet *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'setValueAdded'
        QtMocHelpers::SignalData<void(int, int, QBarSet *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 17 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'setValueRemoved'
        QtMocHelpers::SignalData<void(int, int, QBarSet *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 17 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'handleSetValueChange'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'handleSetValueAdd'
        QtMocHelpers::SlotData<void(int, int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'handleSetValueRemove'
        QtMocHelpers::SlotData<void(int, int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QAbstractBarSeriesPrivate, qt_meta_tag_ZN25QAbstractBarSeriesPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QAbstractBarSeriesPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractSeriesPrivate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QAbstractBarSeriesPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QAbstractBarSeriesPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QAbstractBarSeriesPrivateE_t>.metaTypes,
    nullptr
} };

void QAbstractBarSeriesPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QAbstractBarSeriesPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[2]))); break;
        case 1: _t->pressed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[2]))); break;
        case 2: _t->released((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[2]))); break;
        case 3: _t->doubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[2]))); break;
        case 4: _t->updatedBars(); break;
        case 5: _t->updatedLayout(); break;
        case 6: _t->restructuredBars(); break;
        case 7: _t->labelsVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->visibleChanged(); break;
        case 9: _t->setValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[2]))); break;
        case 10: _t->setValueAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[3]))); break;
        case 11: _t->setValueRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[3]))); break;
        case 12: _t->handleSetValueChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->handleSetValueAdd((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->handleSetValueRemove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)(int , QBarSet * )>(_a, &QAbstractBarSeriesPrivate::clicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)(int , QBarSet * )>(_a, &QAbstractBarSeriesPrivate::pressed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)(int , QBarSet * )>(_a, &QAbstractBarSeriesPrivate::released, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)(int , QBarSet * )>(_a, &QAbstractBarSeriesPrivate::doubleClicked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)()>(_a, &QAbstractBarSeriesPrivate::updatedBars, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)()>(_a, &QAbstractBarSeriesPrivate::updatedLayout, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)()>(_a, &QAbstractBarSeriesPrivate::restructuredBars, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)(bool )>(_a, &QAbstractBarSeriesPrivate::labelsVisibleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)()>(_a, &QAbstractBarSeriesPrivate::visibleChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)(int , QBarSet * )>(_a, &QAbstractBarSeriesPrivate::setValueChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)(int , int , QBarSet * )>(_a, &QAbstractBarSeriesPrivate::setValueAdded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QAbstractBarSeriesPrivate::*)(int , int , QBarSet * )>(_a, &QAbstractBarSeriesPrivate::setValueRemoved, 11))
            return;
    }
}

const QMetaObject *QAbstractBarSeriesPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QAbstractBarSeriesPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QAbstractBarSeriesPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractSeriesPrivate::qt_metacast(_clname);
}

int QAbstractBarSeriesPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractSeriesPrivate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void QAbstractBarSeriesPrivate::clicked(int _t1, QBarSet * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void QAbstractBarSeriesPrivate::pressed(int _t1, QBarSet * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void QAbstractBarSeriesPrivate::released(int _t1, QBarSet * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void QAbstractBarSeriesPrivate::doubleClicked(int _t1, QBarSet * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void QAbstractBarSeriesPrivate::updatedBars()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QAbstractBarSeriesPrivate::updatedLayout()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QAbstractBarSeriesPrivate::restructuredBars()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QAbstractBarSeriesPrivate::labelsVisibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QAbstractBarSeriesPrivate::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QAbstractBarSeriesPrivate::setValueChanged(int _t1, QBarSet * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void QAbstractBarSeriesPrivate::setValueAdded(int _t1, int _t2, QBarSet * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void QAbstractBarSeriesPrivate::setValueRemoved(int _t1, int _t2, QBarSet * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
