/****************************************************************************
** Meta object code from reading C++ file 'declarativeareaseries_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/chartsqml2/declarativeareaseries_p.h"
#include <QtCharts/qlineseries.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativeareaseries_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21DeclarativeAreaSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeAreaSeries::qt_create_metaobjectdata<qt_meta_tag_ZN21DeclarativeAreaSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeAreaSeries",
        "QML.Element",
        "AreaSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "axisXChanged",
        "",
        "QAbstractAxis*",
        "axis",
        "axisYChanged",
        "borderWidthChanged",
        "width",
        "axisXTopChanged",
        "axisYRightChanged",
        "axisAngularChanged",
        "axisRadialChanged",
        "brushChanged",
        "brushFilenameChanged",
        "brushFilename",
        "handleBrushChanged",
        "upperSeries",
        "DeclarativeLineSeries*",
        "lowerSeries",
        "axisX",
        "axisY",
        "axisXTop",
        "axisYRight",
        "axisAngular",
        "axisRadial",
        "borderWidth",
        "brush",
        "QBrush"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(7, 8, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(11, 8, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'borderWidthChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(12, 8, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { QMetaType::QReal, 13 },
        }}),
        // Signal 'axisXTopChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(14, 8, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'axisYRightChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(15, 8, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'axisAngularChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(16, 8, QMC::AccessPublic, 0x103, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'axisRadialChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(17, 8, QMC::AccessPublic, 0x103, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'brushChanged'
        QtMocHelpers::RevisionedSignalData<void()>(18, 8, QMC::AccessPublic, 0x104, QMetaType::Void),
        // Signal 'brushFilenameChanged'
        QtMocHelpers::RevisionedSignalData<void(const QString &)>(19, 8, QMC::AccessPublic, 0x104, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'handleBrushChanged'
        QtMocHelpers::SlotData<void()>(21, 8, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'upperSeries'
        QtMocHelpers::PropertyData<DeclarativeLineSeries*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'lowerSeries'
        QtMocHelpers::PropertyData<DeclarativeLineSeries*>(24, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'axisX'
        QtMocHelpers::PropertyData<QAbstractAxis*>(25, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0, 0x101),
        // property 'axisY'
        QtMocHelpers::PropertyData<QAbstractAxis*>(26, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1, 0x101),
        // property 'axisXTop'
        QtMocHelpers::PropertyData<QAbstractAxis*>(27, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3, 0x102),
        // property 'axisYRight'
        QtMocHelpers::PropertyData<QAbstractAxis*>(28, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4, 0x102),
        // property 'axisAngular'
        QtMocHelpers::PropertyData<QAbstractAxis*>(29, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5, 0x103),
        // property 'axisRadial'
        QtMocHelpers::PropertyData<QAbstractAxis*>(30, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6, 0x103),
        // property 'borderWidth'
        QtMocHelpers::PropertyData<qreal>(31, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2, 0x101),
        // property 'brushFilename'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8, 0x104),
        // property 'brush'
        QtMocHelpers::PropertyData<QBrush>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7, 0x104),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeAreaSeries, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeAreaSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QAreaSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DeclarativeAreaSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DeclarativeAreaSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21DeclarativeAreaSeriesE_t>.metaTypes,
    nullptr
} };

void DeclarativeAreaSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeAreaSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 2: _t->borderWidthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 3: _t->axisXTopChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 4: _t->axisYRightChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 5: _t->axisAngularChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 6: _t->axisRadialChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 7: _t->brushChanged(); break;
        case 8: _t->brushFilenameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->handleBrushChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)(QAbstractAxis * )>(_a, &DeclarativeAreaSeries::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)(QAbstractAxis * )>(_a, &DeclarativeAreaSeries::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)(qreal )>(_a, &DeclarativeAreaSeries::borderWidthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)(QAbstractAxis * )>(_a, &DeclarativeAreaSeries::axisXTopChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)(QAbstractAxis * )>(_a, &DeclarativeAreaSeries::axisYRightChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)(QAbstractAxis * )>(_a, &DeclarativeAreaSeries::axisAngularChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)(QAbstractAxis * )>(_a, &DeclarativeAreaSeries::axisRadialChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)()>(_a, &DeclarativeAreaSeries::brushChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAreaSeries::*)(const QString & )>(_a, &DeclarativeAreaSeries::brushFilenameChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DeclarativeLineSeries* >(); break;
        case 7:
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DeclarativeLineSeries**>(_v) = _t->upperSeries(); break;
        case 1: *reinterpret_cast<DeclarativeLineSeries**>(_v) = _t->lowerSeries(); break;
        case 2: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisX(); break;
        case 3: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisY(); break;
        case 4: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 5: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 6: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisAngular(); break;
        case 7: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisRadial(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->borderWidth(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->brushFilename(); break;
        case 10: *reinterpret_cast<QBrush*>(_v) = _t->brush(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUpperSeries(*reinterpret_cast<DeclarativeLineSeries**>(_v)); break;
        case 1: _t->setLowerSeries(*reinterpret_cast<DeclarativeLineSeries**>(_v)); break;
        case 2: _t->setAxisX(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisY(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 4: _t->setAxisXTop(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 5: _t->setAxisYRight(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 6: _t->setAxisAngular(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 7: _t->setAxisRadial(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 8: _t->setBorderWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 9: _t->setBrushFilename(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setBrush(*reinterpret_cast<QBrush*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeAreaSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeAreaSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DeclarativeAreaSeriesE_t>.strings))
        return static_cast<void*>(this);
    return QAreaSeries::qt_metacast(_clname);
}

int DeclarativeAreaSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAreaSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeAreaSeries::axisXChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeAreaSeries::axisYChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeAreaSeries::borderWidthChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeAreaSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeclarativeAreaSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DeclarativeAreaSeries::axisAngularChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeclarativeAreaSeries::axisRadialChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DeclarativeAreaSeries::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DeclarativeAreaSeries::brushFilenameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
