/****************************************************************************
** Meta object code from reading C++ file 'qcandlestickmodelmapper_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/candlestickchart/qcandlestickmodelmapper_p.h"
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qcandlestickmodelmapper_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30QCandlestickModelMapperPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto QCandlestickModelMapperPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN30QCandlestickModelMapperPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCandlestickModelMapperPrivate",
        "timestampChanged",
        "",
        "openChanged",
        "highChanged",
        "lowChanged",
        "closeChanged",
        "firstSetSectionChanged",
        "lastSetSectionChanged",
        "initializeCandlestickFromModel",
        "modelDataUpdated",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "modelHeaderDataUpdated",
        "Qt::Orientation",
        "orientation",
        "first",
        "last",
        "modelRowsInserted",
        "parent",
        "start",
        "end",
        "modelRowsRemoved",
        "modelColumnsInserted",
        "modelColumnsRemoved",
        "modelDestroyed",
        "candlestickSetsAdded",
        "QList<QCandlestickSet*>",
        "sets",
        "candlestickSetsRemoved",
        "candlestickSetChanged",
        "seriesDestroyed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timestampChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lowChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'firstSetSectionChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastSetSectionChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initializeCandlestickFromModel'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'modelDataUpdated'
        QtMocHelpers::SlotData<void(QModelIndex, QModelIndex)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 13 },
        }}),
        // Slot 'modelHeaderDataUpdated'
        QtMocHelpers::SlotData<void(Qt::Orientation, int, int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Int, 17 }, { QMetaType::Int, 18 },
        }}),
        // Slot 'modelRowsInserted'
        QtMocHelpers::SlotData<void(QModelIndex, int, int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'modelRowsRemoved'
        QtMocHelpers::SlotData<void(QModelIndex, int, int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'modelColumnsInserted'
        QtMocHelpers::SlotData<void(QModelIndex, int, int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'modelColumnsRemoved'
        QtMocHelpers::SlotData<void(QModelIndex, int, int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'modelDestroyed'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'candlestickSetsAdded'
        QtMocHelpers::SlotData<void(const QList<QCandlestickSet*> &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'candlestickSetsRemoved'
        QtMocHelpers::SlotData<void(const QList<QCandlestickSet*> &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'candlestickSetChanged'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'seriesDestroyed'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QCandlestickModelMapperPrivate, qt_meta_tag_ZN30QCandlestickModelMapperPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCandlestickModelMapperPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QCandlestickModelMapperPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QCandlestickModelMapperPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30QCandlestickModelMapperPrivateE_t>.metaTypes,
    nullptr
} };

void QCandlestickModelMapperPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QCandlestickModelMapperPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timestampChanged(); break;
        case 1: _t->openChanged(); break;
        case 2: _t->highChanged(); break;
        case 3: _t->lowChanged(); break;
        case 4: _t->closeChanged(); break;
        case 5: _t->firstSetSectionChanged(); break;
        case 6: _t->lastSetSectionChanged(); break;
        case 7: _t->initializeCandlestickFromModel(); break;
        case 8: _t->modelDataUpdated((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 9: _t->modelHeaderDataUpdated((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 10: _t->modelRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->modelRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 12: _t->modelColumnsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 13: _t->modelColumnsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 14: _t->modelDestroyed(); break;
        case 15: _t->candlestickSetsAdded((*reinterpret_cast<std::add_pointer_t<QList<QCandlestickSet*>>>(_a[1]))); break;
        case 16: _t->candlestickSetsRemoved((*reinterpret_cast<std::add_pointer_t<QList<QCandlestickSet*>>>(_a[1]))); break;
        case 17: _t->candlestickSetChanged(); break;
        case 18: _t->seriesDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QCandlestickModelMapperPrivate::*)()>(_a, &QCandlestickModelMapperPrivate::timestampChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickModelMapperPrivate::*)()>(_a, &QCandlestickModelMapperPrivate::openChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickModelMapperPrivate::*)()>(_a, &QCandlestickModelMapperPrivate::highChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickModelMapperPrivate::*)()>(_a, &QCandlestickModelMapperPrivate::lowChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickModelMapperPrivate::*)()>(_a, &QCandlestickModelMapperPrivate::closeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickModelMapperPrivate::*)()>(_a, &QCandlestickModelMapperPrivate::firstSetSectionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QCandlestickModelMapperPrivate::*)()>(_a, &QCandlestickModelMapperPrivate::lastSetSectionChanged, 6))
            return;
    }
}

const QMetaObject *QCandlestickModelMapperPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCandlestickModelMapperPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QCandlestickModelMapperPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QCandlestickModelMapperPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void QCandlestickModelMapperPrivate::timestampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QCandlestickModelMapperPrivate::openChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QCandlestickModelMapperPrivate::highChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QCandlestickModelMapperPrivate::lowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QCandlestickModelMapperPrivate::closeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QCandlestickModelMapperPrivate::firstSetSectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QCandlestickModelMapperPrivate::lastSetSectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
