/****************************************************************************
** Meta object code from reading C++ file 'qpieslice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/charts/piechart/qpieslice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qpieslice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9QPieSliceE_t {};
} // unnamed namespace

template <> constexpr inline auto QPieSlice::qt_create_metaobjectdata<qt_meta_tag_ZN9QPieSliceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QPieSlice",
        "clicked",
        "",
        "hovered",
        "state",
        "pressed",
        "released",
        "doubleClicked",
        "labelChanged",
        "valueChanged",
        "labelVisibleChanged",
        "penChanged",
        "brushChanged",
        "labelBrushChanged",
        "labelFontChanged",
        "percentageChanged",
        "startAngleChanged",
        "angleSpanChanged",
        "colorChanged",
        "borderColorChanged",
        "borderWidthChanged",
        "labelColorChanged",
        "label",
        "value",
        "labelVisible",
        "labelPosition",
        "LabelPosition",
        "exploded",
        "pen",
        "QPen",
        "borderColor",
        "QColor",
        "borderWidth",
        "brush",
        "QBrush",
        "color",
        "labelBrush",
        "labelColor",
        "labelFont",
        "QFont",
        "labelArmLengthFactor",
        "explodeDistanceFactor",
        "percentage",
        "startAngle",
        "angleSpan",
        "LabelOutside",
        "LabelInsideHorizontal",
        "LabelInsideTangential",
        "LabelInsideNormal"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hovered'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'pressed'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'released'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleClicked'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelVisibleChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'penChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brushChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelBrushChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelFontChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'percentageChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startAngleChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'angleSpanChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderColorChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderWidthChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelColorChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'label'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'value'
        QtMocHelpers::PropertyData<qreal>(23, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'labelVisible'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'labelPosition'
        QtMocHelpers::PropertyData<enum LabelPosition>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'exploded'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pen'
        QtMocHelpers::PropertyData<QPen>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'borderColor'
        QtMocHelpers::PropertyData<QColor>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 16),
        // property 'borderWidth'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'brush'
        QtMocHelpers::PropertyData<QBrush>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(35, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'labelBrush'
        QtMocHelpers::PropertyData<QBrush>(36, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'labelColor'
        QtMocHelpers::PropertyData<QColor>(37, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 18),
        // property 'labelFont'
        QtMocHelpers::PropertyData<QFont>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'labelArmLengthFactor'
        QtMocHelpers::PropertyData<qreal>(40, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'explodeDistanceFactor'
        QtMocHelpers::PropertyData<qreal>(41, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'percentage'
        QtMocHelpers::PropertyData<qreal>(42, QMetaType::QReal, QMC::DefaultPropertyFlags, 12),
        // property 'startAngle'
        QtMocHelpers::PropertyData<qreal>(43, QMetaType::QReal, QMC::DefaultPropertyFlags, 13),
        // property 'angleSpan'
        QtMocHelpers::PropertyData<qreal>(44, QMetaType::QReal, QMC::DefaultPropertyFlags, 14),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LabelPosition'
        QtMocHelpers::EnumData<enum LabelPosition>(26, 26, QMC::EnumFlags{}).add({
            {   45, LabelPosition::LabelOutside },
            {   46, LabelPosition::LabelInsideHorizontal },
            {   47, LabelPosition::LabelInsideTangential },
            {   48, LabelPosition::LabelInsideNormal },
        }),
    };
    return QtMocHelpers::metaObjectData<QPieSlice, qt_meta_tag_ZN9QPieSliceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QPieSlice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QPieSliceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QPieSliceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9QPieSliceE_t>.metaTypes,
    nullptr
} };

void QPieSlice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QPieSlice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->hovered((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->pressed(); break;
        case 3: _t->released(); break;
        case 4: _t->doubleClicked(); break;
        case 5: _t->labelChanged(); break;
        case 6: _t->valueChanged(); break;
        case 7: _t->labelVisibleChanged(); break;
        case 8: _t->penChanged(); break;
        case 9: _t->brushChanged(); break;
        case 10: _t->labelBrushChanged(); break;
        case 11: _t->labelFontChanged(); break;
        case 12: _t->percentageChanged(); break;
        case 13: _t->startAngleChanged(); break;
        case 14: _t->angleSpanChanged(); break;
        case 15: _t->colorChanged(); break;
        case 16: _t->borderColorChanged(); break;
        case 17: _t->borderWidthChanged(); break;
        case 18: _t->labelColorChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::clicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)(bool )>(_a, &QPieSlice::hovered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::pressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::released, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::doubleClicked, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::labelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::valueChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::labelVisibleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::penChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::brushChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::labelBrushChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::labelFontChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::percentageChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::startAngleChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::angleSpanChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::colorChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::borderColorChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::borderWidthChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QPieSlice::*)()>(_a, &QPieSlice::labelColorChanged, 18))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->value(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isLabelVisible(); break;
        case 3: *reinterpret_cast<enum LabelPosition*>(_v) = _t->labelPosition(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isExploded(); break;
        case 5: *reinterpret_cast<QPen*>(_v) = _t->pen(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->borderColor(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->borderWidth(); break;
        case 8: *reinterpret_cast<QBrush*>(_v) = _t->brush(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 10: *reinterpret_cast<QBrush*>(_v) = _t->labelBrush(); break;
        case 11: *reinterpret_cast<QColor*>(_v) = _t->labelColor(); break;
        case 12: *reinterpret_cast<QFont*>(_v) = _t->labelFont(); break;
        case 13: *reinterpret_cast<qreal*>(_v) = _t->labelArmLengthFactor(); break;
        case 14: *reinterpret_cast<qreal*>(_v) = _t->explodeDistanceFactor(); break;
        case 15: *reinterpret_cast<qreal*>(_v) = _t->percentage(); break;
        case 16: *reinterpret_cast<qreal*>(_v) = _t->startAngle(); break;
        case 17: *reinterpret_cast<qreal*>(_v) = _t->angleSpan(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setValue(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setLabelVisible(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setLabelPosition(*reinterpret_cast<enum LabelPosition*>(_v)); break;
        case 4: _t->setExploded(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setPen(*reinterpret_cast<QPen*>(_v)); break;
        case 6: _t->setBorderColor(*reinterpret_cast<QColor*>(_v)); break;
        case 7: _t->setBorderWidth(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setBrush(*reinterpret_cast<QBrush*>(_v)); break;
        case 9: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 10: _t->setLabelBrush(*reinterpret_cast<QBrush*>(_v)); break;
        case 11: _t->setLabelColor(*reinterpret_cast<QColor*>(_v)); break;
        case 12: _t->setLabelFont(*reinterpret_cast<QFont*>(_v)); break;
        case 13: _t->setLabelArmLengthFactor(*reinterpret_cast<qreal*>(_v)); break;
        case 14: _t->setExplodeDistanceFactor(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QPieSlice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QPieSlice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9QPieSliceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QPieSlice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void QPieSlice::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QPieSlice::hovered(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QPieSlice::pressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QPieSlice::released()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QPieSlice::doubleClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QPieSlice::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QPieSlice::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QPieSlice::labelVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QPieSlice::penChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QPieSlice::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QPieSlice::labelBrushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QPieSlice::labelFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QPieSlice::percentageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QPieSlice::startAngleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QPieSlice::angleSpanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QPieSlice::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QPieSlice::borderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QPieSlice::borderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QPieSlice::labelColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}
QT_WARNING_POP
