/****************************************************************************
** Meta object code from reading C++ file 'declarativeforeigntypes_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/chartsqml2/declarativeforeigntypes_p.h"
#include <QtCharts/qabstractbarseries.h>
#include <QtCharts/qvbarmodelmapper.h>
#include <QtCharts/qpieseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCharts/qpieseries.h>
#include <QtCharts/qpieseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCharts/qpieseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCharts/qboxplotseries.h>
#include <QtCharts/qboxplotseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCharts/qboxplotseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCharts/qxyseries.h>
#include <QtCharts/qxyseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCharts/qxyseries.h>
#include <QtCore/qabstractitemmodel.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativeforeigntypes_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18CppQBarModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQBarModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN18CppQBarModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQBarModelMapper",
        "QML.Foreign",
        "QBarModelMapper",
        "QML.Element",
        "BarModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
            {   11,   12 },
    });
    return QtMocHelpers::metaObjectData<CppQBarModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQBarModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQBarModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQBarModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CppQBarModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19CppQHBarModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQHBarModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN19CppQHBarModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQHBarModelMapper",
        "QML.Foreign",
        "QHBarModelMapper",
        "QML.Element",
        "HBarModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<CppQHBarModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQHBarModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQHBarModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQHBarModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CppQHBarModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19CppQVBarModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQVBarModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN19CppQVBarModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQVBarModelMapper",
        "QML.Foreign",
        "QVBarModelMapper",
        "QML.Element",
        "VBarModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<CppQVBarModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQVBarModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQVBarModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQVBarModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CppQVBarModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19CppQBarCategoryAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQBarCategoryAxis::qt_create_metaobjectdata<qt_meta_tag_ZN19CppQBarCategoryAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQBarCategoryAxis",
        "QML.Foreign",
        "QBarCategoryAxis",
        "QML.Element",
        "BarCategoryAxis",
        "BarCategoriesAxis",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    3,    5 },
            {    6,    7 },
            {    8,    9 },
    });
    return QtMocHelpers::metaObjectData<CppQBarCategoryAxis, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQBarCategoryAxis::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQBarCategoryAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQBarCategoryAxisE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CppQBarCategoryAxisE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN21CppQAbstractBarSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQAbstractBarSeries::qt_create_metaobjectdata<qt_meta_tag_ZN21CppQAbstractBarSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQAbstractBarSeries",
        "QML.Foreign",
        "QAbstractBarSeries",
        "QML.Element",
        "AbstractBarSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
            {   11,   12 },
    });
    return QtMocHelpers::metaObjectData<CppQAbstractBarSeries, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQAbstractBarSeries::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21CppQAbstractBarSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21CppQAbstractBarSeriesE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21CppQAbstractBarSeriesE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN14CppQListBarSetE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQListBarSet::qt_create_metaobjectdata<qt_meta_tag_ZN14CppQListBarSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQListBarSet",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QList<QBarSet*>",
        "QML.Sequence",
        "QBarSet*"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CppQListBarSet, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQListBarSet::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CppQListBarSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CppQListBarSetE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14CppQListBarSetE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18CppQPieModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQPieModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN18CppQPieModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQPieModelMapper",
        "QML.Foreign",
        "QPieModelMapper",
        "QML.Element",
        "PieModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
            {   11,   12 },
    });
    return QtMocHelpers::metaObjectData<CppQPieModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQPieModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQPieModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQPieModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CppQPieModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19CppQHPieModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQHPieModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN19CppQHPieModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQHPieModelMapper",
        "QML.Foreign",
        "QHPieModelMapper",
        "QML.Element",
        "HPieModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<CppQHPieModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQHPieModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQHPieModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQHPieModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CppQHPieModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19CppQVPieModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQVPieModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN19CppQVPieModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQVPieModelMapper",
        "QML.Foreign",
        "QVPieModelMapper",
        "QML.Element",
        "VPieModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<CppQVPieModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQVPieModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQVPieModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CppQVPieModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CppQVPieModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN16CppQListPieSliceE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQListPieSlice::qt_create_metaobjectdata<qt_meta_tag_ZN16CppQListPieSliceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQListPieSlice",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QList<QPieSlice*>",
        "QML.Sequence",
        "QPieSlice*"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CppQListPieSlice, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQListPieSlice::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CppQListPieSliceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CppQListPieSliceE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16CppQListPieSliceE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22CppQBoxPlotModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQBoxPlotModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN22CppQBoxPlotModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQBoxPlotModelMapper",
        "QML.Foreign",
        "QBoxPlotModelMapper",
        "QML.Element",
        "BoxPlotModelMapper",
        "QML.AddedInVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
    });
    return QtMocHelpers::metaObjectData<CppQBoxPlotModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQBoxPlotModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22CppQBoxPlotModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22CppQBoxPlotModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22CppQBoxPlotModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23CppQHBoxPlotModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQHBoxPlotModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN23CppQHBoxPlotModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQHBoxPlotModelMapper",
        "QML.Foreign",
        "QHBoxPlotModelMapper",
        "QML.Element",
        "HBoxPlotModelMapper",
        "QML.AddedInVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CppQHBoxPlotModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQHBoxPlotModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CppQHBoxPlotModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CppQHBoxPlotModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23CppQHBoxPlotModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN23CppQVBoxPlotModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQVBoxPlotModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN23CppQVBoxPlotModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQVBoxPlotModelMapper",
        "QML.Foreign",
        "QVBoxPlotModelMapper",
        "QML.Element",
        "VBoxPlotModelMapper",
        "QML.AddedInVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CppQVBoxPlotModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQVBoxPlotModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CppQVBoxPlotModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23CppQVBoxPlotModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23CppQVBoxPlotModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN14CppQListBoxSetE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQListBoxSet::qt_create_metaobjectdata<qt_meta_tag_ZN14CppQListBoxSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQListBoxSet",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QList<QBoxSet*>",
        "QML.Sequence",
        "QBoxSet*"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CppQListBoxSet, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQListBoxSet::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CppQListBoxSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CppQListBoxSetE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14CppQListBoxSetE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26CppQCandlestickModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQCandlestickModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN26CppQCandlestickModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQCandlestickModelMapper",
        "QML.Foreign",
        "QCandlestickModelMapper",
        "QML.Element",
        "CandlestickModelMapper",
        "QML.AddedInVersion",
        "514",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
    });
    return QtMocHelpers::metaObjectData<CppQCandlestickModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQCandlestickModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26CppQCandlestickModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26CppQCandlestickModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26CppQCandlestickModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN27CppQHCandlestickModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQHCandlestickModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN27CppQHCandlestickModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQHCandlestickModelMapper",
        "QML.Foreign",
        "QHCandlestickModelMapper",
        "QML.Element",
        "HCandlestickModelMapper",
        "QML.AddedInVersion",
        "514"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CppQHCandlestickModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQHCandlestickModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27CppQHCandlestickModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27CppQHCandlestickModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27CppQHCandlestickModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN27CppQVCandlestickModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQVCandlestickModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN27CppQVCandlestickModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQVCandlestickModelMapper",
        "QML.Foreign",
        "QVCandlestickModelMapper",
        "QML.Element",
        "VCandlestickModelMapper",
        "QML.AddedInVersion",
        "514"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CppQVCandlestickModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQVCandlestickModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27CppQVCandlestickModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27CppQVCandlestickModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27CppQVCandlestickModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22CppQListCandlestickSetE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQListCandlestickSet::qt_create_metaobjectdata<qt_meta_tag_ZN22CppQListCandlestickSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQListCandlestickSet",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QList<QCandlestickSet*>",
        "QML.Sequence",
        "QCandlestickSet*"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<CppQListCandlestickSet, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQListCandlestickSet::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22CppQListCandlestickSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22CppQListCandlestickSetE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22CppQListCandlestickSetE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN16CppQDateTimeAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQDateTimeAxis::qt_create_metaobjectdata<qt_meta_tag_ZN16CppQDateTimeAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQDateTimeAxis",
        "QML.Foreign",
        "QDateTimeAxis",
        "QML.Element",
        "DateTimeAxis",
        "QML.AddedInVersion",
        "257",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<CppQDateTimeAxis, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQDateTimeAxis::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CppQDateTimeAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CppQDateTimeAxisE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16CppQDateTimeAxisE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN17CppQXYModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQXYModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN17CppQXYModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQXYModelMapper",
        "QML.Foreign",
        "QXYModelMapper",
        "QML.Element",
        "XYModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
            {   11,   12 },
    });
    return QtMocHelpers::metaObjectData<CppQXYModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQXYModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CppQXYModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CppQXYModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CppQXYModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18CppQHXYModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQHXYModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN18CppQHXYModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQHXYModelMapper",
        "QML.Foreign",
        "QHXYModelMapper",
        "QML.Element",
        "HXYModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<CppQHXYModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQHXYModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQHXYModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQHXYModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CppQHXYModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18CppQVXYModelMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQVXYModelMapper::qt_create_metaobjectdata<qt_meta_tag_ZN18CppQVXYModelMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQVXYModelMapper",
        "QML.Foreign",
        "QVXYModelMapper",
        "QML.Element",
        "VXYModelMapper",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<CppQVXYModelMapper, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQVXYModelMapper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQVXYModelMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQVXYModelMapperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CppQVXYModelMapperE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN16CppQAbstractAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQAbstractAxis::qt_create_metaobjectdata<qt_meta_tag_ZN16CppQAbstractAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQAbstractAxis",
        "QML.Foreign",
        "QAbstractAxis",
        "QML.Element",
        "AbstractAxis",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
            {   11,   12 },
    });
    return QtMocHelpers::metaObjectData<CppQAbstractAxis, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQAbstractAxis::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CppQAbstractAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CppQAbstractAxisE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16CppQAbstractAxisE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN13CppQValueAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQValueAxis::qt_create_metaobjectdata<qt_meta_tag_ZN13CppQValueAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQValueAxis",
        "QML.Foreign",
        "QValueAxis",
        "QML.Element",
        "ValueAxis",
        "ValuesAxis",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    3,    5 },
            {    6,    7 },
            {    8,    9 },
    });
    return QtMocHelpers::metaObjectData<CppQValueAxis, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQValueAxis::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CppQValueAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13CppQValueAxisE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13CppQValueAxisE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN16CppQLogValueAxisE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQLogValueAxis::qt_create_metaobjectdata<qt_meta_tag_ZN16CppQLogValueAxisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQLogValueAxis",
        "QML.Foreign",
        "QLogValueAxis",
        "QML.Element",
        "LogValueAxis",
        "QML.AddedInVersion",
        "259",
        "QML.ExtraVersion",
        "512"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<CppQLogValueAxis, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQLogValueAxis::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CppQLogValueAxisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CppQLogValueAxisE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16CppQLogValueAxisE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18CppQAbstractSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQAbstractSeries::qt_create_metaobjectdata<qt_meta_tag_ZN18CppQAbstractSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQAbstractSeries",
        "QML.Foreign",
        "QAbstractSeries",
        "QML.Element",
        "AbstractSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
            {   11,   12 },
    });
    return QtMocHelpers::metaObjectData<CppQAbstractSeries, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQAbstractSeries::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQAbstractSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQAbstractSeriesE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CppQAbstractSeriesE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN12CppQXYSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQXYSeries::qt_create_metaobjectdata<qt_meta_tag_ZN12CppQXYSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQXYSeries",
        "QML.Foreign",
        "QXYSeries",
        "QML.Element",
        "XYSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
            {   11,   12 },
    });
    return QtMocHelpers::metaObjectData<CppQXYSeries, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQXYSeries::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CppQXYSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CppQXYSeriesE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12CppQXYSeriesE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26CppQHashPointConfigurationE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQHashPointConfiguration::qt_create_metaobjectdata<qt_meta_tag_ZN26CppQHashPointConfigurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQHashPointConfiguration",
        "QML.Element",
        "anonymous",
        "QML.Foreign",
        "QXYSeries::PointsConfigurationHash",
        "QML.Extended"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    0 },
    });
    return QtMocHelpers::metaObjectData<CppQHashPointConfiguration, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQHashPointConfiguration::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26CppQHashPointConfigurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26CppQHashPointConfigurationE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26CppQHashPointConfigurationE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN10CppQLegendE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQLegend::qt_create_metaobjectdata<qt_meta_tag_ZN10CppQLegendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQLegend",
        "QML.Foreign",
        "QLegend",
        "QML.Element",
        "Legend",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Uncreatable base type"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
            {   11,   12 },
    });
    return QtMocHelpers::metaObjectData<CppQLegend, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQLegend::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CppQLegendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CppQLegendE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10CppQLegendE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18CppQGraphicsLayoutE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQGraphicsLayout::qt_create_metaobjectdata<qt_meta_tag_ZN18CppQGraphicsLayoutE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQGraphicsLayout",
        "QML.Foreign",
        "QGraphicsLayout",
        "QML.Using",
        "void"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CppQGraphicsLayout, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQGraphicsLayout::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQGraphicsLayoutE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CppQGraphicsLayoutE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CppQGraphicsLayoutE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN7CppQPenE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQPen::qt_create_metaobjectdata<qt_meta_tag_ZN7CppQPenE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQPen",
        "QML.Foreign",
        "QPen",
        "QML.Extended",
        "QML.Element",
        "anonymous"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    0 },
            {    4,    5 },
    });
    return QtMocHelpers::metaObjectData<CppQPen, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQPen::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7CppQPenE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7CppQPenE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7CppQPenE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN9CppQBrushE_t {};
} // unnamed namespace

template <> constexpr inline auto CppQBrush::qt_create_metaobjectdata<qt_meta_tag_ZN9CppQBrushE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CppQBrush",
        "QML.Foreign",
        "QBrush",
        "QML.Extended",
        "QML.Element",
        "anonymous"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    0 },
            {    4,    5 },
    });
    return QtMocHelpers::metaObjectData<CppQBrush, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CppQBrush::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9CppQBrushE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9CppQBrushE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9CppQBrushE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
