/****************************************************************************
** Meta object code from reading C++ file 'declarativebarseries_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/chartsqml2/declarativebarseries_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativebarseries_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DeclarativeBarSetE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeBarSet::qt_create_metaobjectdata<qt_meta_tag_ZN17DeclarativeBarSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeBarSet",
        "QML.Element",
        "BarSet",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "countChanged",
        "",
        "count",
        "borderWidthChanged",
        "width",
        "brushFilenameChanged",
        "brushFilename",
        "handleCountChanged",
        "index",
        "handleBrushChanged",
        "append",
        "value",
        "remove",
        "replace",
        "at",
        "values",
        "QVariantList",
        "borderWidth"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void(int)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'borderWidthChanged'
        QtMocHelpers::RevisionedSignalData<void(qreal)>(10, 8, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { QMetaType::QReal, 11 },
        }}),
        // Signal 'brushFilenameChanged'
        QtMocHelpers::RevisionedSignalData<void(const QString &)>(12, 8, QMC::AccessPublic, 0x104, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'handleCountChanged'
        QtMocHelpers::SlotData<void(int, int)>(14, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'handleBrushChanged'
        QtMocHelpers::SlotData<void()>(16, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'append'
        QtMocHelpers::MethodData<void(qreal)>(17, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 18 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<void(const int, const int)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 9 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<void(const int)>(19, 8, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Method 'replace'
        QtMocHelpers::MethodData<void(int, qreal)>(20, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::QReal, 18 },
        }}),
        // Method 'at'
        QtMocHelpers::MethodData<qreal(int)>(21, 8, QMC::AccessPublic, QMetaType::QReal, {{
            { QMetaType::Int, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'values'
        QtMocHelpers::PropertyData<QVariantList>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'borderWidth'
        QtMocHelpers::PropertyData<qreal>(24, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1, 0x101),
        // property 'count'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'brushFilename'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2, 0x104),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeBarSet, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeBarSet::staticMetaObject = { {
    QMetaObject::SuperData::link<QBarSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeclarativeBarSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeclarativeBarSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DeclarativeBarSetE_t>.metaTypes,
    nullptr
} };

void DeclarativeBarSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeBarSet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->borderWidthChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 2: _t->brushFilenameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->handleCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->handleBrushChanged(); break;
        case 5: _t->append((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 6: _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->replace((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 9: { qreal _r = _t->at((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBarSet::*)(int )>(_a, &DeclarativeBarSet::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBarSet::*)(qreal )>(_a, &DeclarativeBarSet::borderWidthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBarSet::*)(const QString & )>(_a, &DeclarativeBarSet::brushFilenameChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantList*>(_v) = _t->values(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->borderWidth(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->brushFilename(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setValues(*reinterpret_cast<QVariantList*>(_v)); break;
        case 1: _t->setBorderWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setBrushFilename(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeBarSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeBarSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DeclarativeBarSetE_t>.strings))
        return static_cast<void*>(this);
    return QBarSet::qt_metacast(_clname);
}

int DeclarativeBarSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QBarSet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeBarSet::countChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeBarSet::borderWidthChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeBarSet::brushFilenameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN20DeclarativeBarSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeBarSeries::qt_create_metaobjectdata<qt_meta_tag_ZN20DeclarativeBarSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeBarSeries",
        "DefaultProperty",
        "seriesChildren",
        "QML.Element",
        "BarSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "axisXChanged",
        "",
        "QAbstractAxis*",
        "axis",
        "axisYChanged",
        "axisXTopChanged",
        "axisYRightChanged",
        "at",
        "DeclarativeBarSet*",
        "index",
        "append",
        "label",
        "QVariantList",
        "values",
        "insert",
        "remove",
        "QBarSet*",
        "barset",
        "clear",
        "axisX",
        "axisY",
        "axisXTop",
        "axisYRight",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(9, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(13, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisXTopChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(14, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYRightChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(15, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'at'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int)>(16, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<DeclarativeBarSet *(QString, QVariantList)>(19, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'insert'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int, QString, QVariantList)>(23, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(QBarSet *)>(24, 10, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(27, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QAbstractAxis*>(28, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0, 0x101),
        // property 'axisY'
        QtMocHelpers::PropertyData<QAbstractAxis*>(29, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1, 0x101),
        // property 'axisXTop'
        QtMocHelpers::PropertyData<QAbstractAxis*>(30, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2, 0x102),
        // property 'axisYRight'
        QtMocHelpers::PropertyData<QAbstractAxis*>(31, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3, 0x102),
        // property 'seriesChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeBarSeries, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeBarSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QBarSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeclarativeBarSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeclarativeBarSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DeclarativeBarSeriesE_t>.metaTypes,
    nullptr
} };

void DeclarativeBarSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeBarSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 2: _t->axisXTopChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 3: _t->axisYRightChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 4: { DeclarativeBarSet* _r = _t->at((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 5: { DeclarativeBarSet* _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 6: { DeclarativeBarSet* _r = _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBarSet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeBarSeries::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeBarSeries::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeBarSeries::axisXTopChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeBarSeries::axisYRightChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 3: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->seriesChildren(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 2: _t->setAxisXTop(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisYRight(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeBarSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeBarSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeclarativeBarSeriesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QBarSeries::qt_metacast(_clname);
}

int DeclarativeBarSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QBarSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeBarSeries::axisXChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeBarSeries::axisYChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeBarSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeBarSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN27DeclarativeStackedBarSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeStackedBarSeries::qt_create_metaobjectdata<qt_meta_tag_ZN27DeclarativeStackedBarSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeStackedBarSeries",
        "DefaultProperty",
        "seriesChildren",
        "QML.Element",
        "StackedBarSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "axisXChanged",
        "",
        "QAbstractAxis*",
        "axis",
        "axisYChanged",
        "axisXTopChanged",
        "axisYRightChanged",
        "at",
        "DeclarativeBarSet*",
        "index",
        "append",
        "label",
        "QVariantList",
        "values",
        "insert",
        "remove",
        "QBarSet*",
        "barset",
        "clear",
        "axisX",
        "axisY",
        "axisXTop",
        "axisYRight",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(9, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(13, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisXTopChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(14, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYRightChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(15, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'at'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int)>(16, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<DeclarativeBarSet *(QString, QVariantList)>(19, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'insert'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int, QString, QVariantList)>(23, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(QBarSet *)>(24, 10, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(27, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QAbstractAxis*>(28, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0, 0x101),
        // property 'axisY'
        QtMocHelpers::PropertyData<QAbstractAxis*>(29, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1, 0x101),
        // property 'axisXTop'
        QtMocHelpers::PropertyData<QAbstractAxis*>(30, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2, 0x102),
        // property 'axisYRight'
        QtMocHelpers::PropertyData<QAbstractAxis*>(31, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3, 0x102),
        // property 'seriesChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeStackedBarSeries, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeStackedBarSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QStackedBarSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27DeclarativeStackedBarSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27DeclarativeStackedBarSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27DeclarativeStackedBarSeriesE_t>.metaTypes,
    nullptr
} };

void DeclarativeStackedBarSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeStackedBarSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 2: _t->axisXTopChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 3: _t->axisYRightChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 4: { DeclarativeBarSet* _r = _t->at((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 5: { DeclarativeBarSet* _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 6: { DeclarativeBarSet* _r = _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBarSet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeStackedBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeStackedBarSeries::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeStackedBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeStackedBarSeries::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeStackedBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeStackedBarSeries::axisXTopChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeStackedBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeStackedBarSeries::axisYRightChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 3: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->seriesChildren(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 2: _t->setAxisXTop(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisYRight(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeStackedBarSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeStackedBarSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27DeclarativeStackedBarSeriesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QStackedBarSeries::qt_metacast(_clname);
}

int DeclarativeStackedBarSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStackedBarSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeStackedBarSeries::axisXChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeStackedBarSeries::axisYChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeStackedBarSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeStackedBarSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN27DeclarativePercentBarSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativePercentBarSeries::qt_create_metaobjectdata<qt_meta_tag_ZN27DeclarativePercentBarSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativePercentBarSeries",
        "DefaultProperty",
        "seriesChildren",
        "QML.Element",
        "PercentBarSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "axisXChanged",
        "",
        "QAbstractAxis*",
        "axis",
        "axisYChanged",
        "axisXTopChanged",
        "axisYRightChanged",
        "at",
        "DeclarativeBarSet*",
        "index",
        "append",
        "label",
        "QVariantList",
        "values",
        "insert",
        "remove",
        "QBarSet*",
        "barset",
        "clear",
        "axisX",
        "axisY",
        "axisXTop",
        "axisYRight",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(9, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(13, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisXTopChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(14, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYRightChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(15, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'at'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int)>(16, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<DeclarativeBarSet *(QString, QVariantList)>(19, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'insert'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int, QString, QVariantList)>(23, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(QBarSet *)>(24, 10, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(27, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QAbstractAxis*>(28, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0, 0x101),
        // property 'axisY'
        QtMocHelpers::PropertyData<QAbstractAxis*>(29, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1, 0x101),
        // property 'axisXTop'
        QtMocHelpers::PropertyData<QAbstractAxis*>(30, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2, 0x102),
        // property 'axisYRight'
        QtMocHelpers::PropertyData<QAbstractAxis*>(31, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3, 0x102),
        // property 'seriesChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<DeclarativePercentBarSeries, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativePercentBarSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QPercentBarSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27DeclarativePercentBarSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27DeclarativePercentBarSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27DeclarativePercentBarSeriesE_t>.metaTypes,
    nullptr
} };

void DeclarativePercentBarSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativePercentBarSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 2: _t->axisXTopChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 3: _t->axisYRightChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 4: { DeclarativeBarSet* _r = _t->at((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 5: { DeclarativeBarSet* _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 6: { DeclarativeBarSet* _r = _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBarSet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativePercentBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativePercentBarSeries::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativePercentBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativePercentBarSeries::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativePercentBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativePercentBarSeries::axisXTopChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativePercentBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativePercentBarSeries::axisYRightChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 3: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->seriesChildren(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 2: _t->setAxisXTop(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisYRight(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativePercentBarSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativePercentBarSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27DeclarativePercentBarSeriesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QPercentBarSeries::qt_metacast(_clname);
}

int DeclarativePercentBarSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPercentBarSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DeclarativePercentBarSeries::axisXChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativePercentBarSeries::axisYChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativePercentBarSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativePercentBarSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN30DeclarativeHorizontalBarSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeHorizontalBarSeries::qt_create_metaobjectdata<qt_meta_tag_ZN30DeclarativeHorizontalBarSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeHorizontalBarSeries",
        "DefaultProperty",
        "seriesChildren",
        "QML.Element",
        "HorizontalBarSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "axisXChanged",
        "",
        "QAbstractAxis*",
        "axis",
        "axisYChanged",
        "axisXTopChanged",
        "axisYRightChanged",
        "at",
        "DeclarativeBarSet*",
        "index",
        "append",
        "label",
        "QVariantList",
        "values",
        "insert",
        "remove",
        "QBarSet*",
        "barset",
        "clear",
        "axisX",
        "axisY",
        "axisXTop",
        "axisYRight",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(9, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(13, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisXTopChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(14, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYRightChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(15, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'at'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int)>(16, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<DeclarativeBarSet *(QString, QVariantList)>(19, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'insert'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int, QString, QVariantList)>(23, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(QBarSet *)>(24, 10, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(27, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QAbstractAxis*>(28, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0, 0x101),
        // property 'axisY'
        QtMocHelpers::PropertyData<QAbstractAxis*>(29, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1, 0x101),
        // property 'axisXTop'
        QtMocHelpers::PropertyData<QAbstractAxis*>(30, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2, 0x102),
        // property 'axisYRight'
        QtMocHelpers::PropertyData<QAbstractAxis*>(31, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3, 0x102),
        // property 'seriesChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeHorizontalBarSeries, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeHorizontalBarSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QHorizontalBarSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30DeclarativeHorizontalBarSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30DeclarativeHorizontalBarSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30DeclarativeHorizontalBarSeriesE_t>.metaTypes,
    nullptr
} };

void DeclarativeHorizontalBarSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeHorizontalBarSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 2: _t->axisXTopChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 3: _t->axisYRightChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 4: { DeclarativeBarSet* _r = _t->at((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 5: { DeclarativeBarSet* _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 6: { DeclarativeBarSet* _r = _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBarSet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalBarSeries::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalBarSeries::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalBarSeries::axisXTopChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalBarSeries::axisYRightChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 3: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->seriesChildren(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 2: _t->setAxisXTop(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisYRight(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeHorizontalBarSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeHorizontalBarSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30DeclarativeHorizontalBarSeriesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QHorizontalBarSeries::qt_metacast(_clname);
}

int DeclarativeHorizontalBarSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QHorizontalBarSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeHorizontalBarSeries::axisXChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeHorizontalBarSeries::axisYChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeHorizontalBarSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeHorizontalBarSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN37DeclarativeHorizontalStackedBarSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeHorizontalStackedBarSeries::qt_create_metaobjectdata<qt_meta_tag_ZN37DeclarativeHorizontalStackedBarSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeHorizontalStackedBarSeries",
        "DefaultProperty",
        "seriesChildren",
        "QML.Element",
        "HorizontalStackedBarSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "axisXChanged",
        "",
        "QAbstractAxis*",
        "axis",
        "axisYChanged",
        "axisXTopChanged",
        "axisYRightChanged",
        "at",
        "DeclarativeBarSet*",
        "index",
        "append",
        "label",
        "QVariantList",
        "values",
        "insert",
        "remove",
        "QBarSet*",
        "barset",
        "clear",
        "axisX",
        "axisY",
        "axisXTop",
        "axisYRight",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(9, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(13, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisXTopChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(14, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYRightChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(15, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'at'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int)>(16, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<DeclarativeBarSet *(QString, QVariantList)>(19, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'insert'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int, QString, QVariantList)>(23, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(QBarSet *)>(24, 10, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(27, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QAbstractAxis*>(28, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0, 0x101),
        // property 'axisY'
        QtMocHelpers::PropertyData<QAbstractAxis*>(29, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1, 0x101),
        // property 'axisXTop'
        QtMocHelpers::PropertyData<QAbstractAxis*>(30, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2, 0x102),
        // property 'axisYRight'
        QtMocHelpers::PropertyData<QAbstractAxis*>(31, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3, 0x102),
        // property 'seriesChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeHorizontalStackedBarSeries, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeHorizontalStackedBarSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QHorizontalStackedBarSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37DeclarativeHorizontalStackedBarSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37DeclarativeHorizontalStackedBarSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN37DeclarativeHorizontalStackedBarSeriesE_t>.metaTypes,
    nullptr
} };

void DeclarativeHorizontalStackedBarSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeHorizontalStackedBarSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 2: _t->axisXTopChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 3: _t->axisYRightChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 4: { DeclarativeBarSet* _r = _t->at((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 5: { DeclarativeBarSet* _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 6: { DeclarativeBarSet* _r = _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBarSet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalStackedBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalStackedBarSeries::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalStackedBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalStackedBarSeries::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalStackedBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalStackedBarSeries::axisXTopChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalStackedBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalStackedBarSeries::axisYRightChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 3: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->seriesChildren(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 2: _t->setAxisXTop(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisYRight(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeHorizontalStackedBarSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeHorizontalStackedBarSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37DeclarativeHorizontalStackedBarSeriesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QHorizontalStackedBarSeries::qt_metacast(_clname);
}

int DeclarativeHorizontalStackedBarSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QHorizontalStackedBarSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeHorizontalStackedBarSeries::axisXChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeHorizontalStackedBarSeries::axisYChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeHorizontalStackedBarSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeHorizontalStackedBarSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN37DeclarativeHorizontalPercentBarSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeHorizontalPercentBarSeries::qt_create_metaobjectdata<qt_meta_tag_ZN37DeclarativeHorizontalPercentBarSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeHorizontalPercentBarSeries",
        "DefaultProperty",
        "seriesChildren",
        "QML.Element",
        "HorizontalPercentBarSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "axisXChanged",
        "",
        "QAbstractAxis*",
        "axis",
        "axisYChanged",
        "axisXTopChanged",
        "axisYRightChanged",
        "at",
        "DeclarativeBarSet*",
        "index",
        "append",
        "label",
        "QVariantList",
        "values",
        "insert",
        "remove",
        "QBarSet*",
        "barset",
        "clear",
        "axisX",
        "axisY",
        "axisXTop",
        "axisYRight",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(9, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(13, 10, QMC::AccessPublic, 0x101, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisXTopChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(14, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'axisYRightChanged'
        QtMocHelpers::RevisionedSignalData<void(QAbstractAxis *)>(15, 10, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'at'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int)>(16, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<DeclarativeBarSet *(QString, QVariantList)>(19, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'insert'
        QtMocHelpers::MethodData<DeclarativeBarSet *(int, QString, QVariantList)>(23, 10, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(QBarSet *)>(24, 10, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(27, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QAbstractAxis*>(28, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0, 0x101),
        // property 'axisY'
        QtMocHelpers::PropertyData<QAbstractAxis*>(29, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1, 0x101),
        // property 'axisXTop'
        QtMocHelpers::PropertyData<QAbstractAxis*>(30, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2, 0x102),
        // property 'axisYRight'
        QtMocHelpers::PropertyData<QAbstractAxis*>(31, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3, 0x102),
        // property 'seriesChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeHorizontalPercentBarSeries, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeHorizontalPercentBarSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QHorizontalPercentBarSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37DeclarativeHorizontalPercentBarSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37DeclarativeHorizontalPercentBarSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN37DeclarativeHorizontalPercentBarSeriesE_t>.metaTypes,
    nullptr
} };

void DeclarativeHorizontalPercentBarSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeHorizontalPercentBarSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 2: _t->axisXTopChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 3: _t->axisYRightChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 4: { DeclarativeBarSet* _r = _t->at((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 5: { DeclarativeBarSet* _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 6: { DeclarativeBarSet* _r = _t->insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<DeclarativeBarSet**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QBarSet*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBarSet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalPercentBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalPercentBarSeries::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalPercentBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalPercentBarSeries::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalPercentBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalPercentBarSeries::axisXTopChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeHorizontalPercentBarSeries::*)(QAbstractAxis * )>(_a, &DeclarativeHorizontalPercentBarSeries::axisYRightChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 3: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->seriesChildren(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 2: _t->setAxisXTop(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisYRight(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeHorizontalPercentBarSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeHorizontalPercentBarSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37DeclarativeHorizontalPercentBarSeriesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QHorizontalPercentBarSeries::qt_metacast(_clname);
}

int DeclarativeHorizontalPercentBarSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QHorizontalPercentBarSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeHorizontalPercentBarSeries::axisXChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeHorizontalPercentBarSeries::axisYChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeHorizontalPercentBarSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeHorizontalPercentBarSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
