/****************************************************************************
** Meta object code from reading C++ file 'declarativeaxes_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/chartsqml2/declarativeaxes_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativeaxes_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DeclarativeAxesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeAxes::qt_create_metaobjectdata<qt_meta_tag_ZN15DeclarativeAxesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeAxes",
        "QML.Element",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Abstract base type",
        "axisXChanged",
        "",
        "QAbstractAxis*",
        "axis",
        "axisYChanged",
        "axisXTopChanged",
        "axisYRightChanged",
        "axisX",
        "axisY",
        "axisXTop",
        "axisYRight"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'axisXChanged'
        QtMocHelpers::SignalData<void(QAbstractAxis *)>(10, 11, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'axisYChanged'
        QtMocHelpers::SignalData<void(QAbstractAxis *)>(14, 11, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'axisXTopChanged'
        QtMocHelpers::SignalData<void(QAbstractAxis *)>(15, 11, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'axisYRightChanged'
        QtMocHelpers::SignalData<void(QAbstractAxis *)>(16, 11, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'axisX'
        QtMocHelpers::PropertyData<QAbstractAxis*>(17, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'axisY'
        QtMocHelpers::PropertyData<QAbstractAxis*>(18, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'axisXTop'
        QtMocHelpers::PropertyData<QAbstractAxis*>(19, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'axisYRight'
        QtMocHelpers::PropertyData<QAbstractAxis*>(20, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
            {    4,    5 },
            {    6,    7 },
            {    8,    9 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeAxes, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeAxes::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DeclarativeAxesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DeclarativeAxesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DeclarativeAxesE_t>.metaTypes,
    nullptr
} };

void DeclarativeAxes::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeAxes *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 2: _t->axisXTopChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        case 3: _t->axisYRightChanged((*reinterpret_cast<std::add_pointer_t<QAbstractAxis*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractAxis* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAxes::*)(QAbstractAxis * )>(_a, &DeclarativeAxes::axisXChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAxes::*)(QAbstractAxis * )>(_a, &DeclarativeAxes::axisYChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAxes::*)(QAbstractAxis * )>(_a, &DeclarativeAxes::axisXTopChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeAxes::*)(QAbstractAxis * )>(_a, &DeclarativeAxes::axisYRightChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisX(); break;
        case 1: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisY(); break;
        case 2: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 3: *reinterpret_cast<QAbstractAxis**>(_v) = _t->axisYRight(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAxisX(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 1: _t->setAxisY(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 2: _t->setAxisXTop(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisYRight(*reinterpret_cast<QAbstractAxis**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeAxes::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeAxes::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DeclarativeAxesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeclarativeAxes::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeAxes::axisXChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeAxes::axisYChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeAxes::axisXTopChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeAxes::axisYRightChanged(QAbstractAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
