/****************************************************************************
** Meta object code from reading C++ file 'declarativepieseries_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtcharts/src/chartsqml2/declarativepieseries_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativepieseries_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19DeclarativePieSliceE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativePieSlice::qt_create_metaobjectdata<qt_meta_tag_ZN19DeclarativePieSliceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativePieSlice",
        "QML.Element",
        "PieSlice",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "brushFilenameChanged",
        "",
        "brushFilename",
        "handleBrushChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'brushFilenameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'handleBrushChanged'
        QtMocHelpers::SlotData<void()>(10, 8, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'brushFilename'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativePieSlice, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativePieSlice::staticMetaObject = { {
    QMetaObject::SuperData::link<QPieSlice::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativePieSliceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativePieSliceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DeclarativePieSliceE_t>.metaTypes,
    nullptr
} };

void DeclarativePieSlice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativePieSlice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->brushFilenameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->handleBrushChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativePieSlice::*)(const QString & )>(_a, &DeclarativePieSlice::brushFilenameChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->brushFilename(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBrushFilename(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativePieSlice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativePieSlice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DeclarativePieSliceE_t>.strings))
        return static_cast<void*>(this);
    return QPieSlice::qt_metacast(_clname);
}

int DeclarativePieSlice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPieSlice::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DeclarativePieSlice::brushFilenameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN20DeclarativePieSeriesE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativePieSeries::qt_create_metaobjectdata<qt_meta_tag_ZN20DeclarativePieSeriesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativePieSeries",
        "DefaultProperty",
        "seriesChildren",
        "QML.Element",
        "PieSeries",
        "QML.AddedInVersion",
        "256",
        "QML.ExtraVersion",
        "512",
        "sliceAdded",
        "",
        "QPieSlice*",
        "slice",
        "sliceRemoved",
        "handleAdded",
        "QList<QPieSlice*>",
        "slices",
        "handleRemoved",
        "at",
        "index",
        "find",
        "label",
        "append",
        "DeclarativePieSlice*",
        "value",
        "remove",
        "clear",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sliceAdded'
        QtMocHelpers::SignalData<void(QPieSlice *)>(9, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'sliceRemoved'
        QtMocHelpers::SignalData<void(QPieSlice *)>(13, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'handleAdded'
        QtMocHelpers::SlotData<void(const QList<QPieSlice*> &)>(14, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'handleRemoved'
        QtMocHelpers::SlotData<void(const QList<QPieSlice*> &)>(17, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'at'
        QtMocHelpers::MethodData<QPieSlice *(int)>(18, 10, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 19 },
        }}),
        // Method 'find'
        QtMocHelpers::MethodData<QPieSlice *(QString)>(20, 10, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<DeclarativePieSlice *(QString, qreal)>(22, 10, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 21 }, { QMetaType::QReal, 24 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(QPieSlice *)>(25, 10, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(26, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'seriesChildren'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<DeclarativePieSeries, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativePieSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QPieSeries::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeclarativePieSeriesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeclarativePieSeriesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DeclarativePieSeriesE_t>.metaTypes,
    nullptr
} };

void DeclarativePieSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativePieSeries *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sliceAdded((*reinterpret_cast<std::add_pointer_t<QPieSlice*>>(_a[1]))); break;
        case 1: _t->sliceRemoved((*reinterpret_cast<std::add_pointer_t<QPieSlice*>>(_a[1]))); break;
        case 2: _t->handleAdded((*reinterpret_cast<std::add_pointer_t<QList<QPieSlice*>>>(_a[1]))); break;
        case 3: _t->handleRemoved((*reinterpret_cast<std::add_pointer_t<QList<QPieSlice*>>>(_a[1]))); break;
        case 4: { QPieSlice* _r = _t->at((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPieSlice**>(_a[0]) = std::move(_r); }  break;
        case 5: { QPieSlice* _r = _t->find((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPieSlice**>(_a[0]) = std::move(_r); }  break;
        case 6: { DeclarativePieSlice* _r = _t->append((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])));
            if (_a[0]) *reinterpret_cast<DeclarativePieSlice**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QPieSlice*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QPieSlice* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QPieSlice* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QPieSlice*> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QPieSlice*> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QPieSlice* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativePieSeries::*)(QPieSlice * )>(_a, &DeclarativePieSeries::sliceAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativePieSeries::*)(QPieSlice * )>(_a, &DeclarativePieSeries::sliceRemoved, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->seriesChildren(); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativePieSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativePieSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeclarativePieSeriesE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QPieSeries::qt_metacast(_clname);
}

int DeclarativePieSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPieSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DeclarativePieSeries::sliceAdded(QPieSlice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativePieSeries::sliceRemoved(QPieSlice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
